Module: Google::Apis::NetworksecurityV1beta1

Defined in:
lib/google/apis/networksecurity_v1beta1.rb,
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/service.rb,
lib/google/apis/networksecurity_v1beta1/gem_version.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Network Security API

Defined Under Namespace

Classes: AddAddressGroupItemsRequest, AddressGroup, AntivirusOverride, AuthorizationPolicy, AuthzPolicy, AuthzPolicyAuthzRule, AuthzPolicyAuthzRuleFrom, AuthzPolicyAuthzRuleFromRequestSource, AuthzPolicyAuthzRuleHeaderMatch, AuthzPolicyAuthzRuleIpBlock, AuthzPolicyAuthzRulePrincipal, AuthzPolicyAuthzRuleRequestResource, AuthzPolicyAuthzRuleRequestResourceTagValueIdSet, AuthzPolicyAuthzRuleStringMatch, AuthzPolicyAuthzRuleTo, AuthzPolicyAuthzRuleToRequestOperation, AuthzPolicyAuthzRuleToRequestOperationHeaderSet, AuthzPolicyCustomProvider, AuthzPolicyCustomProviderAuthzExtension, AuthzPolicyCustomProviderCloudIap, AuthzPolicyTarget, BackendAuthenticationConfig, CancelOperationRequest, CertificateProviderInstance, ClientTlsPolicy, CloneAddressGroupItemsRequest, CustomInterceptProfile, CustomMirroringProfile, Destination, DnsThreatDetector, Empty, Expr, FirewallEndpoint, FirewallEndpointAssociation, FirewallEndpointAssociationReference, FirewallEndpointEndpointSettings, GatewaySecurityPolicy, GatewaySecurityPolicyRule, GoogleCloudNetworksecurityV1beta1CertificateProvider, GoogleCloudNetworksecurityV1beta1GrpcEndpoint, GoogleIamV1AuditConfig, GoogleIamV1AuditLogConfig, GoogleIamV1Binding, GoogleIamV1Policy, GoogleIamV1SetIamPolicyRequest, GoogleIamV1TestIamPermissionsRequest, GoogleIamV1TestIamPermissionsResponse, HttpHeaderMatch, InterceptDeployment, InterceptDeploymentGroup, InterceptDeploymentGroupConnectedEndpointGroup, InterceptDeploymentGroupDeployment, InterceptEndpointGroup, InterceptEndpointGroupAssociation, InterceptEndpointGroupAssociationDetails, InterceptEndpointGroupAssociationLocationDetails, InterceptEndpointGroupConnectedDeploymentGroup, InterceptLocation, ListAddressGroupReferencesResponse, ListAddressGroupReferencesResponseAddressGroupReference, ListAddressGroupsResponse, ListAuthorizationPoliciesResponse, ListAuthzPoliciesResponse, ListBackendAuthenticationConfigsResponse, ListClientTlsPoliciesResponse, ListDnsThreatDetectorsResponse, ListFirewallEndpointAssociationsResponse, ListFirewallEndpointsResponse, ListGatewaySecurityPoliciesResponse, ListGatewaySecurityPolicyRulesResponse, ListInterceptDeploymentGroupsResponse, ListInterceptDeploymentsResponse, ListInterceptEndpointGroupAssociationsResponse, ListInterceptEndpointGroupsResponse, ListLocationsResponse, ListMirroringDeploymentGroupsResponse, ListMirroringDeploymentsResponse, ListMirroringEndpointGroupAssociationsResponse, ListMirroringEndpointGroupsResponse, ListOperationsResponse, ListSacAttachmentsResponse, ListSacRealmsResponse, ListSecurityProfileGroupsResponse, ListSecurityProfilesResponse, ListServerTlsPoliciesResponse, ListTlsInspectionPoliciesResponse, ListUrlListsResponse, Location, MirroringDeployment, MirroringDeploymentGroup, MirroringDeploymentGroupConnectedEndpointGroup, MirroringDeploymentGroupDeployment, MirroringEndpointGroup, MirroringEndpointGroupAssociation, MirroringEndpointGroupAssociationDetails, MirroringEndpointGroupAssociationLocationDetails, MirroringEndpointGroupConnectedDeploymentGroup, MirroringLocation, MtlsPolicy, NetworkSecurityService, Operation, OperationMetadata, RemoveAddressGroupItemsRequest, Rule, SacAttachment, SacAttachmentSacAttachmentSymantecOptions, SacRealm, SacRealmPairingKey, SacRealmSacRealmSymantecOptions, SecurityProfile, SecurityProfileGroup, ServerTlsPolicy, SeverityOverride, Source, Status, ThreatOverride, ThreatPreventionProfile, TlsInspectionPolicy, UrlFilter, UrlFilteringProfile, UrlList, ValidationCa

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-networksecurity_v1beta1 gem

"0.61.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260131"
VERSION =

Version of the Network Security API this client connects to. This is NOT the gem version.

'V1beta1'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'