Class: Google::Apis::NetworksecurityV1beta1::AntivirusOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Defines what action to take for antivirus threats per protocol.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AntivirusOverride

Returns a new instance of AntivirusOverride.



149
150
151
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 149

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Required. Threat action override. For some threat types, only a subset of actions applies. Corresponds to the JSON property action

Returns:

  • (String)


142
143
144
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 142

def action
  @action
end

#protocolString

Required. Protocol to match. Corresponds to the JSON property protocol

Returns:

  • (String)


147
148
149
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 147

def protocol
  @protocol
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



154
155
156
157
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 154

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @protocol = args[:protocol] if args.key?(:protocol)
end