Class: Google::Apis::NetworksecurityV1beta1::AuthorizationPolicy
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::AuthorizationPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
AuthorizationPolicy is a resource that specifies how a server should authorize incoming connections. This resource in itself does not change the configuration unless it's attached to a target https proxy or endpoint config selector resource.
Instance Attribute Summary collapse
-
#action ⇒ String
Required.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Required.
-
#rules ⇒ Array<Google::Apis::NetworksecurityV1beta1::Rule>
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuthorizationPolicy
constructor
A new instance of AuthorizationPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuthorizationPolicy
Returns a new instance of AuthorizationPolicy.
207 208 209 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 207 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Required. The action to take when a rule match is found. Possible values are "
ALLOW" or "DENY".
Corresponds to the JSON property action
171 172 173 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 171 def action @action end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
176 177 178 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 176 def create_time @create_time end |
#description ⇒ String
Optional. Free-text description of the resource.
Corresponds to the JSON property description
181 182 183 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 181 def description @description end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the AuthorizationPolicy resource.
Corresponds to the JSON property labels
186 187 188 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 186 def labels @labels end |
#name ⇒ String
Required. Name of the AuthorizationPolicy resource. It matches pattern
projects/project/locations/location/authorizationPolicies/.
Corresponds to the JSON property name
192 193 194 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 192 def name @name end |
#rules ⇒ Array<Google::Apis::NetworksecurityV1beta1::Rule>
Optional. List of rules to match. Note that at least one of the rules must
match in order for the action specified in the 'action' field to be taken. A
rule is a match if there is a matching source and destination. If left blank,
the action specified in the action field will be applied on every request.
Corresponds to the JSON property rules
200 201 202 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 200 def rules @rules end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
205 206 207 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 205 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
212 213 214 215 216 217 218 219 220 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 212 def update!(**args) @action = args[:action] if args.key?(:action) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @rules = args[:rules] if args.key?(:rules) @update_time = args[:update_time] if args.key?(:update_time) end |