Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Conditions to match against the incoming request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthzPolicyAuthzRule

Returns a new instance of AuthzPolicyAuthzRule.



348
349
350
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fromGoogle::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleFrom

Describes properties of one or more sources of a request. Corresponds to the JSON property from



334
335
336
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 334

def from
  @from
end

#toGoogle::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleTo

Describes properties of one or more targets of a request. Corresponds to the JSON property to



339
340
341
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 339

def to
  @to
end

#whenString

Optional. CEL expression that describes the conditions to be satisfied for the action. The result of the CEL expression is ANDed with the from and to. Refer to the CEL language reference for a list of available attributes. Corresponds to the JSON property when

Returns:

  • (String)


346
347
348
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 346

def when
  @when
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



353
354
355
356
357
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 353

def update!(**args)
  @from = args[:from] if args.key?(:from)
  @to = args[:to] if args.key?(:to)
  @when = args[:when] if args.key?(:when)
end