Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleFrom
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleFrom
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Describes properties of one or more sources of a request.
Instance Attribute Summary collapse
-
#not_sources ⇒ Array<Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleFromRequestSource>
Optional.
-
#sources ⇒ Array<Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleFromRequestSource>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuthzPolicyAuthzRuleFrom
constructor
A new instance of AuthzPolicyAuthzRuleFrom.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuthzPolicyAuthzRuleFrom
Returns a new instance of AuthzPolicyAuthzRuleFrom.
381 382 383 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 381 def initialize(**args) update!(**args) end |
Instance Attribute Details
#not_sources ⇒ Array<Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleFromRequestSource>
Optional. Describes the negated properties of request sources. Matches
requests from sources that do not match the criteria specified in this field.
At least one of sources or notSources must be specified.
Corresponds to the JSON property notSources
369 370 371 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 369 def not_sources @not_sources end |
#sources ⇒ Array<Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleFromRequestSource>
Optional. Describes the properties of a request's sources. At least one of
sources or notSources must be specified. Limited to 1 source. A match occurs
when ANY source (in sources or notSources) matches the request. Within a
single source, the match follows AND semantics across fields and OR semantics
within a single field, i.e. a match occurs when ANY principal matches AND ANY
ipBlocks match.
Corresponds to the JSON property sources
379 380 381 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 379 def sources @sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
386 387 388 389 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 386 def update!(**args) @not_sources = args[:not_sources] if args.key?(:not_sources) @sources = args[:sources] if args.key?(:sources) end |