Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRulePrincipal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Describes the properties of a principal to be matched against.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthzPolicyAuthzRulePrincipal

Returns a new instance of AuthzPolicyAuthzRulePrincipal.



500
501
502
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 500

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#principalGoogle::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleStringMatch

Determines how a string value should be matched. Corresponds to the JSON property principal



492
493
494
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 492

def principal
  @principal
end

#principal_selectorString

Optional. An enum to decide what principal value the principal rule will match against. If not specified, the PrincipalSelector is CLIENT_CERT_URI_SAN. Corresponds to the JSON property principalSelector

Returns:

  • (String)


498
499
500
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 498

def principal_selector
  @principal_selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



505
506
507
508
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 505

def update!(**args)
  @principal = args[:principal] if args.key?(:principal)
  @principal_selector = args[:principal_selector] if args.key?(:principal_selector)
end