Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleRequestResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Describes the properties of a client VM resource accessing the internal application load balancers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthzPolicyAuthzRuleRequestResource

Returns a new instance of AuthzPolicyAuthzRuleRequestResource.



517
518
519
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 517

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#iam_service_accountGoogle::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleStringMatch

Determines how a string value should be matched. Corresponds to the JSON property iamServiceAccount



509
510
511
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 509

def 
  @iam_service_account
end

#tag_value_id_setGoogle::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleRequestResourceTagValueIdSet

Describes a set of resource tag value permanent IDs to match against the resource manager tags value associated with the source VM of a request. Corresponds to the JSON property tagValueIdSet



515
516
517
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 515

def tag_value_id_set
  @tag_value_id_set
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



522
523
524
525
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 522

def update!(**args)
  @iam_service_account = args[:iam_service_account] if args.key?(:iam_service_account)
  @tag_value_id_set = args[:tag_value_id_set] if args.key?(:tag_value_id_set)
end