Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleStringMatch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Determines how a string value should be matched.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthzPolicyAuthzRuleStringMatch

Returns a new instance of AuthzPolicyAuthzRuleStringMatch.



600
601
602
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 600

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containsString

The input string must have the substring specified here. Note: empty contains match is not allowed, please use regex instead. Examples: * abc matches the value xyz.abc.def Corresponds to the JSON property contains

Returns:

  • (String)


570
571
572
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 570

def contains
  @contains
end

#exactString

The input string must match exactly the string specified here. Examples: * abc only matches the value abc. Corresponds to the JSON property exact

Returns:

  • (String)


576
577
578
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 576

def exact
  @exact
end

#ignore_caseBoolean Also known as: ignore_case?

If true, indicates the exact/prefix/suffix/contains matching should be case insensitive. For example, the matcher data will match both input string Data and data if set to true. Corresponds to the JSON property ignoreCase

Returns:

  • (Boolean)


583
584
585
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 583

def ignore_case
  @ignore_case
end

#prefixString

The input string must have the prefix specified here. Note: empty prefix is not allowed, please use regex instead. Examples: * abc matches the value abc.xyz Corresponds to the JSON property prefix

Returns:

  • (String)


591
592
593
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 591

def prefix
  @prefix
end

#suffixString

The input string must have the suffix specified here. Note: empty prefix is not allowed, please use regex instead. Examples: * abc matches the value xyz.abc Corresponds to the JSON property suffix

Returns:

  • (String)


598
599
600
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 598

def suffix
  @suffix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



605
606
607
608
609
610
611
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 605

def update!(**args)
  @contains = args[:contains] if args.key?(:contains)
  @exact = args[:exact] if args.key?(:exact)
  @ignore_case = args[:ignore_case] if args.key?(:ignore_case)
  @prefix = args[:prefix] if args.key?(:prefix)
  @suffix = args[:suffix] if args.key?(:suffix)
end