Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleToRequestOperationMcp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Describes a set of MCP protocol attributes to match against for a given MCP request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthzPolicyAuthzRuleToRequestOperationMcp

Returns a new instance of AuthzPolicyAuthzRuleToRequestOperationMcp.



755
756
757
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 755

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_protocol_methods_optionString

Optional. If specified, matches on the MCP protocol’s non-access specific methods namely: * initialize * completion/ * logging/ * notifications/ * ping Defaults to SKIP_BASE_PROTOCOL_METHODS if not specified. Corresponds to the JSON property baseProtocolMethodsOption

Returns:

  • (String)


744
745
746
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 744

def base_protocol_methods_option
  @base_protocol_methods_option
end

#methods_propArray<Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleToRequestOperationMcpMethod>

Optional. A list of MCP methods and associated parameters to match on. It is recommended to use this field to match on tools, prompts and resource accesses while setting the baseProtocolMethodsOption to MATCH_BASE_PROTOCOL_METHODS to match on all the other MCP protocol methods. Limited to 10 MCP methods per Authorization Policy. Corresponds to the JSON property methods



753
754
755
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 753

def methods_prop
  @methods_prop
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



760
761
762
763
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 760

def update!(**args)
  @base_protocol_methods_option = args[:base_protocol_methods_option] if args.key?(:base_protocol_methods_option)
  @methods_prop = args[:methods_prop] if args.key?(:methods_prop)
end