Class: Google::Apis::NetworksecurityV1beta1::FirewallEndpointEndpointSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Settings for the endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallEndpointEndpointSettings

Returns a new instance of FirewallEndpointEndpointSettings.



1575
1576
1577
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1575

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_cloud_regionString

Optional. The content cloud region of the endpoint. Corresponds to the JSON property contentCloudRegion

Returns:

  • (String)


1557
1558
1559
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1557

def content_cloud_region
  @content_cloud_region
end

#http_partial_response_blockedBoolean Also known as: http_partial_response_blocked?

Optional. Whether to block HTTP partial responses for the endpoint. When this is true, resumption of blocked malicious HTTP file downloads will be blocked by the firewall. False provides maximum availability, true provides maximum security. Corresponds to the JSON property httpPartialResponseBlocked

Returns:

  • (Boolean)


1565
1566
1567
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1565

def http_partial_response_blocked
  @http_partial_response_blocked
end

#jumbo_frames_enabledBoolean Also known as: jumbo_frames_enabled?

Optional. Immutable. Indicates whether Jumbo Frames are enabled. Default value is false. Corresponds to the JSON property jumboFramesEnabled

Returns:

  • (Boolean)


1572
1573
1574
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1572

def jumbo_frames_enabled
  @jumbo_frames_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1580
1581
1582
1583
1584
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1580

def update!(**args)
  @content_cloud_region = args[:content_cloud_region] if args.key?(:content_cloud_region)
  @http_partial_response_blocked = args[:http_partial_response_blocked] if args.key?(:http_partial_response_blocked)
  @jumbo_frames_enabled = args[:jumbo_frames_enabled] if args.key?(:jumbo_frames_enabled)
end