Class: Google::Apis::NetworksecurityV1beta1::GatewaySecurityPolicyRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

The GatewaySecurityPolicyRule resource is in a nested collection within a GatewaySecurityPolicy and represents a traffic matching condition and associated action to perform.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GatewaySecurityPolicyRule

Returns a new instance of GatewaySecurityPolicyRule.



1783
1784
1785
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1783

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#application_matcherString

Optional. CEL expression for matching on L7/application level criteria. Corresponds to the JSON property applicationMatcher

Returns:

  • (String)


1730
1731
1732
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1730

def application_matcher
  @application_matcher
end

#basic_profileString

Required. Profile which tells what the primitive action should be. Corresponds to the JSON property basicProfile

Returns:

  • (String)


1735
1736
1737
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1735

def basic_profile
  @basic_profile
end

#create_timeString

Output only. Time when the rule was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1740
1741
1742
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1740

def create_time
  @create_time
end

#descriptionString

Optional. Free-text description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


1745
1746
1747
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1745

def description
  @description
end

#enabledBoolean Also known as: enabled?

Required. Whether the rule is enforced. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


1750
1751
1752
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1750

def enabled
  @enabled
end

#nameString

Required. Immutable. Name of the resource. ame is the full resource name so projects/project/locations/location/gatewaySecurityPolicies/ gateway_security_policy/rules/rule rule should match the pattern: (^a-z?$). Corresponds to the JSON property name

Returns:

  • (String)


1759
1760
1761
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1759

def name
  @name
end

#priorityFixnum

Required. Priority of the rule. Lower number corresponds to higher precedence. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


1764
1765
1766
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1764

def priority
  @priority
end

#session_matcherString

Required. CEL expression for matching on session criteria. Corresponds to the JSON property sessionMatcher

Returns:

  • (String)


1769
1770
1771
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1769

def session_matcher
  @session_matcher
end

#tls_inspection_enabledBoolean Also known as: tls_inspection_enabled?

Optional. Flag to enable TLS inspection of traffic matching on , can only be true if the parent GatewaySecurityPolicy references a TLSInspectionConfig. Corresponds to the JSON property tlsInspectionEnabled

Returns:

  • (Boolean)


1775
1776
1777
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1775

def tls_inspection_enabled
  @tls_inspection_enabled
end

#update_timeString

Output only. Time when the rule was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1781
1782
1783
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1781

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1788

def update!(**args)
  @application_matcher = args[:application_matcher] if args.key?(:application_matcher)
  @basic_profile = args[:basic_profile] if args.key?(:basic_profile)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @enabled = args[:enabled] if args.key?(:enabled)
  @name = args[:name] if args.key?(:name)
  @priority = args[:priority] if args.key?(:priority)
  @session_matcher = args[:session_matcher] if args.key?(:session_matcher)
  @tls_inspection_enabled = args[:tls_inspection_enabled] if args.key?(:tls_inspection_enabled)
  @update_time = args[:update_time] if args.key?(:update_time)
end