Class: Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

An endpoint group is a consumer frontend for a deployment group (backend). In order to configure intercept for a network, consumers must create: - An association between their network and the endpoint group. - A security profile that points to the endpoint group. - A firewall rule that references the security profile (group).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterceptEndpointGroup

Returns a new instance of InterceptEndpointGroup.



2540
2541
2542
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2540

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associationsArray<Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroupAssociationDetails>

Output only. List of associations to this endpoint group. Corresponds to the JSON property associations



2480
2481
2482
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2480

def associations
  @associations
end

#connected_deployment_groupGoogle::Apis::NetworksecurityV1beta1::InterceptEndpointGroupConnectedDeploymentGroup

The endpoint group's view of a connected deployment group. Corresponds to the JSON property connectedDeploymentGroup



2485
2486
2487
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2485

def connected_deployment_group
  @connected_deployment_group
end

#create_timeString

Output only. The timestamp when the resource was created. See https://google. aip.dev/148#timestamps. Corresponds to the JSON property createTime

Returns:

  • (String)


2491
2492
2493
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2491

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description of the endpoint group. Used as additional context for the endpoint group. Corresponds to the JSON property description

Returns:

  • (String)


2497
2498
2499
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2497

def description
  @description
end

#intercept_deployment_groupString

Required. Immutable. The deployment group that this endpoint group is connected to, for example: projects/123456789/locations/global/ interceptDeploymentGroups/my-dg. See https://google.aip.dev/124. Corresponds to the JSON property interceptDeploymentGroup

Returns:

  • (String)


2504
2505
2506
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2504

def intercept_deployment_group
  @intercept_deployment_group
end

#labelsHash<String,String>

Optional. Labels are key/value pairs that help to organize and filter resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2510
2511
2512
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2510

def labels
  @labels
end

#nameString

Immutable. Identifier. The resource name of this endpoint group, for example: projects/123456789/locations/global/interceptEndpointGroups/my-eg. See https:/ /google.aip.dev/122 for more details. Corresponds to the JSON property name

Returns:

  • (String)


2517
2518
2519
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2517

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new association to the group). See https:// google.aip.dev/128. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


2525
2526
2527
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2525

def reconciling
  @reconciling
end

#stateString

Output only. The current state of the endpoint group. See https://google.aip. dev/216. Corresponds to the JSON property state

Returns:

  • (String)


2532
2533
2534
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2532

def state
  @state
end

#update_timeString

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps. Corresponds to the JSON property updateTime

Returns:

  • (String)


2538
2539
2540
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2538

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2545

def update!(**args)
  @associations = args[:associations] if args.key?(:associations)
  @connected_deployment_group = args[:connected_deployment_group] if args.key?(:connected_deployment_group)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @intercept_deployment_group = args[:intercept_deployment_group] if args.key?(:intercept_deployment_group)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end