Class: Google::Apis::NetworksecurityV1beta1::ListFirewallEndpointAssociationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::ListFirewallEndpointAssociationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Message for response to listing Associations
Instance Attribute Summary collapse
-
#firewall_endpoint_associations ⇒ Array<Google::Apis::NetworksecurityV1beta1::FirewallEndpointAssociation>
The list of Association Corresponds to the JSON property
firewallEndpointAssociations. -
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFirewallEndpointAssociationsResponse
constructor
A new instance of ListFirewallEndpointAssociationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFirewallEndpointAssociationsResponse
Returns a new instance of ListFirewallEndpointAssociationsResponse.
2901 2902 2903 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#firewall_endpoint_associations ⇒ Array<Google::Apis::NetworksecurityV1beta1::FirewallEndpointAssociation>
The list of Association
Corresponds to the JSON property firewallEndpointAssociations
2889 2890 2891 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2889 def firewall_endpoint_associations @firewall_endpoint_associations end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
2894 2895 2896 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2894 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
2899 2900 2901 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2899 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2906 2907 2908 2909 2910 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2906 def update!(**args) @firewall_endpoint_associations = args[:firewall_endpoint_associations] if args.key?(:firewall_endpoint_associations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |