Class: Google::Apis::NetworksecurityV1beta1::ListFirewallEndpointsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::ListFirewallEndpointsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Message for response to listing Endpoints
Instance Attribute Summary collapse
-
#firewall_endpoints ⇒ Array<Google::Apis::NetworksecurityV1beta1::FirewallEndpoint>
The list of Endpoint Corresponds to the JSON property
firewallEndpoints. -
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFirewallEndpointsResponse
constructor
A new instance of ListFirewallEndpointsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFirewallEndpointsResponse
Returns a new instance of ListFirewallEndpointsResponse.
2840 2841 2842 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#firewall_endpoints ⇒ Array<Google::Apis::NetworksecurityV1beta1::FirewallEndpoint>
The list of Endpoint
Corresponds to the JSON property firewallEndpoints
2828 2829 2830 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2828 def firewall_endpoints @firewall_endpoints end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
2833 2834 2835 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2833 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
2838 2839 2840 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2838 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2845 2846 2847 2848 2849 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2845 def update!(**args) @firewall_endpoints = args[:firewall_endpoints] if args.key?(:firewall_endpoints) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |