Class: Google::Apis::NetworksecurityV1beta1::ListGatewaySecurityPoliciesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Response returned by the ListGatewaySecurityPolicies method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGatewaySecurityPoliciesResponse

Returns a new instance of ListGatewaySecurityPoliciesResponse.



2873
2874
2875
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2873

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gateway_security_policiesArray<Google::Apis::NetworksecurityV1beta1::GatewaySecurityPolicy>

List of GatewaySecurityPolicies resources. Corresponds to the JSON property gatewaySecurityPolicies



2859
2860
2861
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2859

def gateway_security_policies
  @gateway_security_policies
end

#next_page_tokenString

If there might be more results than those appearing in this response, then ' next_page_token' is included. To get the next set of results, call this method again using the value of 'next_page_token' as 'page_token'. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2866
2867
2868
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2866

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2871
2872
2873
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2871

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2878
2879
2880
2881
2882
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2878

def update!(**args)
  @gateway_security_policies = args[:gateway_security_policies] if args.key?(:gateway_security_policies)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end