Class: Google::Apis::NetworksecurityV1beta1::ListGatewaySecurityPolicyRulesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Response returned by the ListGatewaySecurityPolicyRules method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGatewaySecurityPolicyRulesResponse

Returns a new instance of ListGatewaySecurityPolicyRulesResponse.



3019
3020
3021
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gateway_security_policy_rulesArray<Google::Apis::NetworksecurityV1beta1::GatewaySecurityPolicyRule>

List of GatewaySecurityPolicyRule resources. Corresponds to the JSON property gatewaySecurityPolicyRules



3005
3006
3007
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3005

def gateway_security_policy_rules
  @gateway_security_policy_rules
end

#next_page_tokenString

If there might be more results than those appearing in this response, then ' next_page_token' is included. To get the next set of results, call this method again using the value of 'next_page_token' as 'page_token'. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3012
3013
3014
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3012

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3017
3018
3019
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3017

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3024
3025
3026
3027
3028
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3024

def update!(**args)
  @gateway_security_policy_rules = args[:gateway_security_policy_rules] if args.key?(:gateway_security_policy_rules)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end