Class: Google::Apis::NetworksecurityV1beta1::ListSacAttachmentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::ListSacAttachmentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Response for ListSACAttachments method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#sac_attachments ⇒ Array<Google::Apis::NetworksecurityV1beta1::SacAttachment>
The list of SACAttachments.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSacAttachmentsResponse
constructor
A new instance of ListSacAttachmentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSacAttachmentsResponse
Returns a new instance of ListSacAttachmentsResponse.
3224 3225 3226 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
3212 3213 3214 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3212 def next_page_token @next_page_token end |
#sac_attachments ⇒ Array<Google::Apis::NetworksecurityV1beta1::SacAttachment>
The list of SACAttachments.
Corresponds to the JSON property sacAttachments
3217 3218 3219 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3217 def @sac_attachments end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
3222 3223 3224 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3222 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3229 3230 3231 3232 3233 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3229 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @sac_attachments = args[:sac_attachments] if args.key?(:sac_attachments) @unreachable = args[:unreachable] if args.key?(:unreachable) end |