Class: Google::Apis::NetworksecurityV1beta1::ListSecurityProfilesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Response returned by the ListSecurityProfiles method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSecurityProfilesResponse

Returns a new instance of ListSecurityProfilesResponse.



3402
3403
3404
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3395
3396
3397
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3395

def next_page_token
  @next_page_token
end

#security_profilesArray<Google::Apis::NetworksecurityV1beta1::SecurityProfile>

List of SecurityProfile resources. Corresponds to the JSON property securityProfiles



3400
3401
3402
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3400

def security_profiles
  @security_profiles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3407
3408
3409
3410
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3407

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @security_profiles = args[:security_profiles] if args.key?(:security_profiles)
end