Class: Google::Apis::NetworksecurityV1beta1::ListWildfireVerdictChangeRequestsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::ListWildfireVerdictChangeRequestsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Message for response to listing WildfireVerdictChangeRequests.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Unordered list.
-
#wildfire_verdict_change_requests ⇒ Array<Google::Apis::NetworksecurityV1beta1::WildfireVerdictChangeRequest>
The list of WildfireVerdictChangeRequests Corresponds to the JSON property
wildfireVerdictChangeRequests.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListWildfireVerdictChangeRequestsResponse
constructor
A new instance of ListWildfireVerdictChangeRequestsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListWildfireVerdictChangeRequestsResponse
Returns a new instance of ListWildfireVerdictChangeRequestsResponse.
3664 3665 3666 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3664 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
3652 3653 3654 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3652 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
3657 3658 3659 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3657 def unreachable @unreachable end |
#wildfire_verdict_change_requests ⇒ Array<Google::Apis::NetworksecurityV1beta1::WildfireVerdictChangeRequest>
The list of WildfireVerdictChangeRequests
Corresponds to the JSON property wildfireVerdictChangeRequests
3662 3663 3664 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3662 def wildfire_verdict_change_requests @wildfire_verdict_change_requests end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3669 3670 3671 3672 3673 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3669 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) @wildfire_verdict_change_requests = args[:wildfire_verdict_change_requests] if args.key?(:wildfire_verdict_change_requests) end |