Class: Google::Apis::NetworksecurityV1beta1::MirroringEndpointGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

An endpoint group is a consumer frontend for a deployment group (backend). In order to configure mirroring for a network, consumers must create: - An association between their network and the endpoint group. - A security profile that points to the endpoint group. - A mirroring rule that references the security profile (group).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MirroringEndpointGroup

Returns a new instance of MirroringEndpointGroup.



4067
4068
4069
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4067

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associationsArray<Google::Apis::NetworksecurityV1beta1::MirroringEndpointGroupAssociationDetails>

Output only. List of associations to this endpoint group. Corresponds to the JSON property associations



4000
4001
4002
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4000

def associations
  @associations
end

#connected_deployment_groupsArray<Google::Apis::NetworksecurityV1beta1::MirroringEndpointGroupConnectedDeploymentGroup>

Output only. List of details about the connected deployment groups to this endpoint group. Corresponds to the JSON property connectedDeploymentGroups



4006
4007
4008
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4006

def connected_deployment_groups
  @connected_deployment_groups
end

#create_timeString

Output only. The timestamp when the resource was created. See https://google. aip.dev/148#timestamps. Corresponds to the JSON property createTime

Returns:

  • (String)


4012
4013
4014
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4012

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description of the endpoint group. Used as additional context for the endpoint group. Corresponds to the JSON property description

Returns:

  • (String)


4018
4019
4020
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4018

def description
  @description
end

#labelsHash<String,String>

Optional. Labels are key/value pairs that help to organize and filter resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4024
4025
4026
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4024

def labels
  @labels
end

#mirroring_deployment_groupString

Immutable. The deployment group that this DIRECT endpoint group is connected to, for example: projects/123456789/locations/global/ mirroringDeploymentGroups/my-dg. See https://google.aip.dev/124. Corresponds to the JSON property mirroringDeploymentGroup

Returns:

  • (String)


4031
4032
4033
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4031

def mirroring_deployment_group
  @mirroring_deployment_group
end

#nameString

Immutable. Identifier. The resource name of this endpoint group, for example: projects/123456789/locations/global/mirroringEndpointGroups/my-eg. See https:/ /google.aip.dev/122 for more details. Corresponds to the JSON property name

Returns:

  • (String)


4038
4039
4040
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4038

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new association to the group). See https:// google.aip.dev/128. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


4046
4047
4048
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4046

def reconciling
  @reconciling
end

#stateString

Output only. The current state of the endpoint group. See https://google.aip. dev/216. Corresponds to the JSON property state

Returns:

  • (String)


4053
4054
4055
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4053

def state
  @state
end

#typeString

Immutable. The type of the endpoint group. If left unspecified, defaults to DIRECT. Corresponds to the JSON property type

Returns:

  • (String)


4059
4060
4061
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4059

def type
  @type
end

#update_timeString

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps. Corresponds to the JSON property updateTime

Returns:

  • (String)


4065
4066
4067
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4065

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
4083
4084
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4072

def update!(**args)
  @associations = args[:associations] if args.key?(:associations)
  @connected_deployment_groups = args[:connected_deployment_groups] if args.key?(:connected_deployment_groups)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @mirroring_deployment_group = args[:mirroring_deployment_group] if args.key?(:mirroring_deployment_group)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end