Class: Google::Apis::NetworksecurityV1beta1::MirroringEndpointGroupAssociationLocationDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Contains details about the state of an association in a specific cloud location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MirroringEndpointGroupAssociationLocationDetails

Returns a new instance of MirroringEndpointGroupAssociationLocationDetails.



3975
3976
3977
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3975

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationString

Output only. The cloud location, e.g. "us-central1-a" or "asia-south1". Corresponds to the JSON property location

Returns:

  • (String)


3968
3969
3970
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3968

def location
  @location
end

#stateString

Output only. The current state of the association in this location. Corresponds to the JSON property state

Returns:

  • (String)


3973
3974
3975
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3973

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3980
3981
3982
3983
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3980

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @state = args[:state] if args.key?(:state)
end