Class: Google::Apis::NetworksecurityV1beta1::MtlsPolicy
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::MtlsPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Specification of the MTLSPolicy.
Instance Attribute Summary collapse
-
#client_validation_ca ⇒ Array<Google::Apis::NetworksecurityV1beta1::ValidationCa>
Required if the policy is to be used with Traffic Director.
-
#client_validation_mode ⇒ String
When the client presents an invalid certificate or no certificate to the load balancer, the
client_validation_modespecifies how the client connection is handled. -
#client_validation_trust_config ⇒ String
Reference to the TrustConfig from certificatemanager.googleapis.com namespace.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MtlsPolicy
constructor
A new instance of MtlsPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MtlsPolicy
Returns a new instance of MtlsPolicy.
3750 3751 3752 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3750 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_validation_ca ⇒ Array<Google::Apis::NetworksecurityV1beta1::ValidationCa>
Required if the policy is to be used with Traffic Director. For Application
Load Balancers it must be empty. Defines the mechanism to obtain the
Certificate Authority certificate to validate the client certificate.
Corresponds to the JSON property clientValidationCa
3732 3733 3734 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3732 def client_validation_ca @client_validation_ca end |
#client_validation_mode ⇒ String
When the client presents an invalid certificate or no certificate to the load
balancer, the client_validation_mode specifies how the client connection is
handled. Required if the policy is to be used with the Application Load
Balancers. For Traffic Director it must be empty.
Corresponds to the JSON property clientValidationMode
3740 3741 3742 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3740 def client_validation_mode @client_validation_mode end |
#client_validation_trust_config ⇒ String
Reference to the TrustConfig from certificatemanager.googleapis.com namespace.
If specified, the chain validation will be performed against certificates
configured in the given TrustConfig. Allowed only if the policy is to be used
with Application Load Balancers.
Corresponds to the JSON property clientValidationTrustConfig
3748 3749 3750 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3748 def client_validation_trust_config @client_validation_trust_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3755 3756 3757 3758 3759 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3755 def update!(**args) @client_validation_ca = args[:client_validation_ca] if args.key?(:client_validation_ca) @client_validation_mode = args[:client_validation_mode] if args.key?(:client_validation_mode) @client_validation_trust_config = args[:client_validation_trust_config] if args.key?(:client_validation_trust_config) end |