Class: Google::Apis::NetworksecurityV1beta1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



4397
4398
4399
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


4361
4362
4363
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4361

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4366
4367
4368
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4366

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


4371
4372
4373
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4371

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


4379
4380
4381
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4379

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


4385
4386
4387
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4385

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


4390
4391
4392
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4390

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


4395
4396
4397
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4395

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4402
4403
4404
4405
4406
4407
4408
4409
4410
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4402

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end