Class: Google::Apis::NetworksecurityV1beta1::SacAttachment
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::SacAttachment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Represents a Secure Access Connect (SAC) attachment resource. A Secure Access Connect attachment enables NCC Gateway to process traffic with an SSE product.
Instance Attribute Summary collapse
-
#country ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#ncc_gateway ⇒ String
Required.
-
#sac_realm ⇒ String
Required.
-
#state ⇒ String
Output only.
-
#symantec_options ⇒ Google::Apis::NetworksecurityV1beta1::SacAttachmentSacAttachmentSymantecOptions
Fields specific to attachments associated with Symantec Cloud SWG.
-
#time_zone ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SacAttachment
constructor
A new instance of SacAttachment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SacAttachment
Returns a new instance of SacAttachment.
4400 4401 4402 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country ⇒ String
Optional. Case-insensitive ISO-3166 alpha-2 country code used for localization.
Only valid for Symantec attachments.
Corresponds to the JSON property country
4347 4348 4349 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4347 def country @country end |
#create_time ⇒ String
Output only. Timestamp when the attachment was created.
Corresponds to the JSON property createTime
4352 4353 4354 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4352 def create_time @create_time end |
#labels ⇒ Hash<String,String>
Optional. Optional list of labels applied to the resource.
Corresponds to the JSON property labels
4357 4358 4359 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4357 def labels @labels end |
#name ⇒ String
Identifier. Resource name, in the form projects/project/locations/location
/sacAttachments/sac_attachment`.
Corresponds to the JSON propertyname`
4363 4364 4365 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4363 def name @name end |
#ncc_gateway ⇒ String
Required. NCC Gateway associated with the attachment. This can be input as an
ID or a full resource name. The output always has the form projects/
project_number/locations/location/spokes/ncc_gateway`.
Corresponds to the JSON propertynccGateway`
4370 4371 4372 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4370 def ncc_gateway @ncc_gateway end |
#sac_realm ⇒ String
Required. SAC Realm which owns the attachment. This can be input as an ID or a
full resource name. The output always has the form projects/project_number/
locations/location/sacRealms/sac_realm`.
Corresponds to the JSON propertysacRealm`
4377 4378 4379 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4377 def sac_realm @sac_realm end |
#state ⇒ String
Output only. State of the attachment.
Corresponds to the JSON property state
4382 4383 4384 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4382 def state @state end |
#symantec_options ⇒ Google::Apis::NetworksecurityV1beta1::SacAttachmentSacAttachmentSymantecOptions
Fields specific to attachments associated with Symantec Cloud SWG.
Corresponds to the JSON property symantecOptions
4387 4388 4389 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4387 def @symantec_options end |
#time_zone ⇒ String
Optional. Case-sensitive tzinfo identifier used for localization. Only valid
for Symantec attachments.
Corresponds to the JSON property timeZone
4393 4394 4395 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4393 def time_zone @time_zone end |
#update_time ⇒ String
Output only. Timestamp when the attachment was last updated.
Corresponds to the JSON property updateTime
4398 4399 4400 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4398 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4405 4406 4407 4408 4409 4410 4411 4412 4413 4414 4415 4416 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4405 def update!(**args) @country = args[:country] if args.key?(:country) @create_time = args[:create_time] if args.key?(:create_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway) @sac_realm = args[:sac_realm] if args.key?(:sac_realm) @state = args[:state] if args.key?(:state) @symantec_options = args[:symantec_options] if args.key?(:symantec_options) @time_zone = args[:time_zone] if args.key?(:time_zone) @update_time = args[:update_time] if args.key?(:update_time) end |