Class: Google::Apis::NetworksecurityV1beta1::SacAttachmentSacAttachmentSymantecOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Fields specific to attachments associated with Symantec Cloud SWG.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SacAttachmentSacAttachmentSymantecOptions

Returns a new instance of SacAttachmentSacAttachmentSymantecOptions.



4585
4586
4587
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#symantec_location_nameString

Immutable. Name to be used when creating a location on the customer's behalf in Symantec's Location API. Not to be confused with Google Cloud locations. Corresponds to the JSON property symantecLocationName

Returns:

  • (String)


4577
4578
4579
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4577

def symantec_location_name
  @symantec_location_name
end

#symantec_siteString

Immutable. Symantec data center identifier that this attachment will connect to. Corresponds to the JSON property symantecSite

Returns:

  • (String)


4583
4584
4585
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4583

def symantec_site
  @symantec_site
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4590
4591
4592
4593
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4590

def update!(**args)
  @symantec_location_name = args[:symantec_location_name] if args.key?(:symantec_location_name)
  @symantec_site = args[:symantec_site] if args.key?(:symantec_site)
end