Class: Google::Apis::NetworksecurityV1beta1::SacRealmSacRealmSymantecOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Fields specific to realms using Symantec Cloud SWG.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SacRealmSacRealmSymantecOptions

Returns a new instance of SacRealmSacRealmSymantecOptions.



4446
4447
4448
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4446

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_symantec_sitesArray<String>

Output only. Symantec site IDs which the user can choose to connect to. Corresponds to the JSON property availableSymantecSites

Returns:

  • (Array<String>)


4430
4431
4432
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4430

def available_symantec_sites
  @available_symantec_sites
end

#secret_pathString

Optional. API Key used to call Symantec APIs on the user's behalf. Required if using Symantec Cloud SWG. P4SA account needs permissions granted to read this secret. A secret ID, secret name, or secret URI can be specified, but it will be parsed and stored as a secret URI in the form projects/project_number/ secrets/my-secret. Corresponds to the JSON property secretPath

Returns:

  • (String)


4439
4440
4441
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4439

def secret_path
  @secret_path
end

#symantec_connection_stateString

Output only. Connection status to Symantec API. Corresponds to the JSON property symantecConnectionState

Returns:

  • (String)


4444
4445
4446
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4444

def symantec_connection_state
  @symantec_connection_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4451
4452
4453
4454
4455
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4451

def update!(**args)
  @available_symantec_sites = args[:available_symantec_sites] if args.key?(:available_symantec_sites)
  @secret_path = args[:secret_path] if args.key?(:secret_path)
  @symantec_connection_state = args[:symantec_connection_state] if args.key?(:symantec_connection_state)
end