Class: Google::Apis::NetworksecurityV1beta1::SecurityProfileGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

SecurityProfileGroup is a resource that defines the behavior for various ProfileTypes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityProfileGroup

Returns a new instance of SecurityProfileGroup.



4888
4889
4890
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Resource creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


4822
4823
4824
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4822

def create_time
  @create_time
end

#custom_intercept_profileString

Optional. Reference to a SecurityProfile with the CustomIntercept configuration. Corresponds to the JSON property customInterceptProfile

Returns:

  • (String)


4828
4829
4830
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4828

def custom_intercept_profile
  @custom_intercept_profile
end

#custom_mirroring_profileString

Optional. Reference to a SecurityProfile with the CustomMirroring configuration. Corresponds to the JSON property customMirroringProfile

Returns:

  • (String)


4834
4835
4836
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4834

def custom_mirroring_profile
  @custom_mirroring_profile
end

#data_path_idFixnum

Output only. Identifier used by the data-path. Unique within container, location. Corresponds to the JSON property dataPathId

Returns:

  • (Fixnum)


4840
4841
4842
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4840

def data_path_id
  @data_path_id
end

#descriptionString

Optional. An optional description of the profile group. Max length 2048 characters. Corresponds to the JSON property description

Returns:

  • (String)


4846
4847
4848
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4846

def description
  @description
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4853
4854
4855
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4853

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4858
4859
4860
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4858

def labels
  @labels
end

#nameString

Immutable. Identifier. Name of the SecurityProfileGroup resource. It matches pattern projects|organizations/*/locations/location/securityProfileGroups/ security_profile_group`. Corresponds to the JSON propertyname`

Returns:

  • (String)


4865
4866
4867
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4865

def name
  @name
end

#threat_prevention_profileString

Optional. Reference to a SecurityProfile with the ThreatPrevention configuration. Corresponds to the JSON property threatPreventionProfile

Returns:

  • (String)


4871
4872
4873
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4871

def threat_prevention_profile
  @threat_prevention_profile
end

#update_timeString

Output only. Last resource update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


4876
4877
4878
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4876

def update_time
  @update_time
end

#url_filtering_profileString

Optional. Reference to a SecurityProfile with the UrlFiltering configuration. Corresponds to the JSON property urlFilteringProfile

Returns:

  • (String)


4881
4882
4883
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4881

def url_filtering_profile
  @url_filtering_profile
end

#wildfire_analysis_profileString

Optional. Reference to a SecurityProfile with the WildFire configuration. Corresponds to the JSON property wildfireAnalysisProfile

Returns:

  • (String)


4886
4887
4888
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4886

def wildfire_analysis_profile
  @wildfire_analysis_profile
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4893
4894
4895
4896
4897
4898
4899
4900
4901
4902
4903
4904
4905
4906
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4893

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile)
  @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile)
  @data_path_id = args[:data_path_id] if args.key?(:data_path_id)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile)
  @update_time = args[:update_time] if args.key?(:update_time)
  @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile)
  @wildfire_analysis_profile = args[:wildfire_analysis_profile] if args.key?(:wildfire_analysis_profile)
end