Class: Google::Apis::NetworksecurityV1beta1::ThreatOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Defines what action to take for a specific threat_id match.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ThreatOverride

Returns a new instance of ThreatOverride.



5106
5107
5108
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5106

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Required. Threat action override. For some threat types, only a subset of actions applies. Corresponds to the JSON property action

Returns:

  • (String)


5094
5095
5096
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5094

def action
  @action
end

#threat_idString

Required. Vendor-specific ID of a threat to override. Corresponds to the JSON property threatId

Returns:

  • (String)


5099
5100
5101
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5099

def threat_id
  @threat_id
end

#typeString

Output only. Type of the threat (read only). Corresponds to the JSON property type

Returns:

  • (String)


5104
5105
5106
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5104

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5111
5112
5113
5114
5115
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5111

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @threat_id = args[:threat_id] if args.key?(:threat_id)
  @type = args[:type] if args.key?(:type)
end