Class: Google::Apis::NetworksecurityV1beta1::ThreatPreventionProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

ThreatPreventionProfile defines an action for specific threat signatures or severity levels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ThreatPreventionProfile

Returns a new instance of ThreatPreventionProfile.



4865
4866
4867
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#antivirus_overridesArray<Google::Apis::NetworksecurityV1beta1::AntivirusOverride>

Optional. Configuration for overriding antivirus actions per protocol. Corresponds to the JSON property antivirusOverrides



4851
4852
4853
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4851

def antivirus_overrides
  @antivirus_overrides
end

#severity_overridesArray<Google::Apis::NetworksecurityV1beta1::SeverityOverride>

Optional. Configuration for overriding threats actions by severity match. Corresponds to the JSON property severityOverrides



4856
4857
4858
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4856

def severity_overrides
  @severity_overrides
end

#threat_overridesArray<Google::Apis::NetworksecurityV1beta1::ThreatOverride>

Optional. Configuration for overriding threats actions by threat_id match. If a threat is matched both by configuration provided in severity_overrides and threat_overrides, the threat_overrides action is applied. Corresponds to the JSON property threatOverrides



4863
4864
4865
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4863

def threat_overrides
  @threat_overrides
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4870
4871
4872
4873
4874
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4870

def update!(**args)
  @antivirus_overrides = args[:antivirus_overrides] if args.key?(:antivirus_overrides)
  @severity_overrides = args[:severity_overrides] if args.key?(:severity_overrides)
  @threat_overrides = args[:threat_overrides] if args.key?(:threat_overrides)
end