Class: Google::Apis::NetworksecurityV1beta1::WildfireVerdictChangeRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Message for a WildfireVerdictChangeRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WildfireVerdictChangeRequest

Returns a new instance of WildfireVerdictChangeRequest.



5797
5798
5799
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5797

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commentString

Required. The justification for the verdict change request. Max length 2048 characters. Corresponds to the JSON property comment

Returns:

  • (String)


5721
5722
5723
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5721

def comment
  @comment
end

#create_timeString

Output only. The timestamp when the WildfireVerdictChangeRequest was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5726
5727
5728
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5726

def create_time
  @create_time
end

#file_nameString

Output only. The file name of the Malware Sample. Corresponds to the JSON property fileName

Returns:

  • (String)


5731
5732
5733
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5731

def file_name
  @file_name
end

#file_typeString

Output only. The file type of the Malware Sample. Corresponds to the JSON property fileType

Returns:

  • (String)


5736
5737
5738
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5736

def file_type
  @file_type
end

#final_verdictString

Output only. The final verdict of the Malware Sample. Corresponds to the JSON property finalVerdict

Returns:

  • (String)


5741
5742
5743
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5741

def final_verdict
  @final_verdict
end

#nameString

Output only. Identifier. The relative name of the WildfireVerdictChangeRequest. Output only. This is a unique identifier generated by the third party API. Format: organizations|projects/project_or_organization/locations/location/ firewallEndpoints/firewall_endpoint/wildfireVerdictChangeRequests/ wildfire_verdict_change_request_id Where wildfire_verdict_change_request_id is the ID in the format: ^[0-9a-fA-F]8-[0-9a-fA-F]4-[0-9a-fA-F]4-[0-9a- fA-F]4-[0-9a-fA-F]12$ Corresponds to the JSON property name

Returns:

  • (String)


5752
5753
5754
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5752

def name
  @name
end

#new_verdictString

Required. The suggested verdict to apply to the Malware Sample. Corresponds to the JSON property newVerdict

Returns:

  • (String)


5757
5758
5759
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5757

def new_verdict
  @new_verdict
end

#old_verdictString

Output only. The original verdict of the Malware Sample. Corresponds to the JSON property oldVerdict

Returns:

  • (String)


5762
5763
5764
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5762

def old_verdict
  @old_verdict
end

#resolution_timeString

Output only. The timestamp when the WildfireVerdictChangeRequest was resolved. Corresponds to the JSON property resolutionTime

Returns:

  • (String)


5767
5768
5769
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5767

def resolution_time
  @resolution_time
end

#sha256String

Required. The SHA256 hash of the Malware Sample to change the verdict of. Corresponds to the JSON property sha256

Returns:

  • (String)


5772
5773
5774
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5772

def sha256
  @sha256
end

#source_regionString

Output only. The region of the file associated with the Malware Sample. Corresponds to the JSON property sourceRegion

Returns:

  • (String)


5777
5778
5779
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5777

def source_region
  @source_region
end

#stateString

Output only. The review state of the WildfireVerdictChangeRequest. Corresponds to the JSON property state

Returns:

  • (String)


5782
5783
5784
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5782

def state
  @state
end

#update_timeString

Output only. The timestamp when the WildfireVerdictChangeRequest was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5788
5789
5790
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5788

def update_time
  @update_time
end

#wildfire_verdict_change_request_idString

Output only. The ID of the WildfireVerdictChangeRequest. This is a unique identifier generated by the third party API. Format: ^[0-9a-fA-F]8-[0-9a-fA- F]4-[0-9a-fA-F]4-[0-9a-fA-F]4-[0-9a-fA-F]12$ Corresponds to the JSON property wildfireVerdictChangeRequestId

Returns:

  • (String)


5795
5796
5797
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5795

def wildfire_verdict_change_request_id
  @wildfire_verdict_change_request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5802
5803
5804
5805
5806
5807
5808
5809
5810
5811
5812
5813
5814
5815
5816
5817
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5802

def update!(**args)
  @comment = args[:comment] if args.key?(:comment)
  @create_time = args[:create_time] if args.key?(:create_time)
  @file_name = args[:file_name] if args.key?(:file_name)
  @file_type = args[:file_type] if args.key?(:file_type)
  @final_verdict = args[:final_verdict] if args.key?(:final_verdict)
  @name = args[:name] if args.key?(:name)
  @new_verdict = args[:new_verdict] if args.key?(:new_verdict)
  @old_verdict = args[:old_verdict] if args.key?(:old_verdict)
  @resolution_time = args[:resolution_time] if args.key?(:resolution_time)
  @sha256 = args[:sha256] if args.key?(:sha256)
  @source_region = args[:source_region] if args.key?(:source_region)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
  @wildfire_verdict_change_request_id = args[:wildfire_verdict_change_request_id] if args.key?(:wildfire_verdict_change_request_id)
end