Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRule
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Conditions to match against the incoming request.
Instance Attribute Summary collapse
-
#from ⇒ Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleFrom
Describes properties of one or more sources of a request.
-
#to ⇒ Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleTo
Describes properties of one or more targets of a request.
-
#when ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuthzPolicyAuthzRule
constructor
A new instance of AuthzPolicyAuthzRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuthzPolicyAuthzRule
Returns a new instance of AuthzPolicyAuthzRule.
330 331 332 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 330 def initialize(**args) update!(**args) end |
Instance Attribute Details
#from ⇒ Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleFrom
Describes properties of one or more sources of a request.
Corresponds to the JSON property from
316 317 318 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 316 def from @from end |
#to ⇒ Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleTo
Describes properties of one or more targets of a request.
Corresponds to the JSON property to
321 322 323 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 321 def to @to end |
#when ⇒ String
Optional. CEL expression that describes the conditions to be satisfied for the
action. The result of the CEL expression is ANDed with the from and to. Refer
to the CEL language reference for a list of available attributes.
Corresponds to the JSON property when
328 329 330 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 328 def when @when end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
335 336 337 338 339 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 335 def update!(**args) @from = args[:from] if args.key?(:from) @to = args[:to] if args.key?(:to) @when = args[:when] if args.key?(:when) end |