Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleFrom

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Describes properties of one or more sources of a request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthzPolicyAuthzRuleFrom

Returns a new instance of AuthzPolicyAuthzRuleFrom.



363
364
365
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#not_sourcesArray<Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleFromRequestSource>

Optional. Describes the negated properties of request sources. Matches requests from sources that do not match the criteria specified in this field. At least one of sources or notSources must be specified. Corresponds to the JSON property notSources



351
352
353
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 351

def not_sources
  @not_sources
end

#sourcesArray<Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleFromRequestSource>

Optional. Describes the properties of a request's sources. At least one of sources or notSources must be specified. Limited to 1 source. A match occurs when ANY source (in sources or notSources) matches the request. Within a single source, the match follows AND semantics across fields and OR semantics within a single field, i.e. a match occurs when ANY principal matches AND ANY ipBlocks match. Corresponds to the JSON property sources



361
362
363
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 361

def sources
  @sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



368
369
370
371
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 368

def update!(**args)
  @not_sources = args[:not_sources] if args.key?(:not_sources)
  @sources = args[:sources] if args.key?(:sources)
end