Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRulePrincipal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Describes the properties of a principal to be matched against.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthzPolicyAuthzRulePrincipal

Returns a new instance of AuthzPolicyAuthzRulePrincipal.



482
483
484
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#principalGoogle::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleStringMatch

Determines how a string value should be matched. Corresponds to the JSON property principal



474
475
476
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 474

def principal
  @principal
end

#principal_selectorString

Optional. An enum to decide what principal value the principal rule will match against. If not specified, the PrincipalSelector is CLIENT_CERT_URI_SAN. Corresponds to the JSON property principalSelector

Returns:

  • (String)


480
481
482
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 480

def principal_selector
  @principal_selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



487
488
489
490
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 487

def update!(**args)
  @principal = args[:principal] if args.key?(:principal)
  @principal_selector = args[:principal_selector] if args.key?(:principal_selector)
end