Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleStringMatch
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleStringMatch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Determines how a string value should be matched.
Instance Attribute Summary collapse
-
#contains ⇒ String
The input string must have the substring specified here.
-
#exact ⇒ String
The input string must match exactly the string specified here.
-
#ignore_case ⇒ Boolean
(also: #ignore_case?)
If true, indicates the exact/prefix/suffix/contains matching should be case insensitive.
-
#prefix ⇒ String
The input string must have the prefix specified here.
-
#suffix ⇒ String
The input string must have the suffix specified here.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuthzPolicyAuthzRuleStringMatch
constructor
A new instance of AuthzPolicyAuthzRuleStringMatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuthzPolicyAuthzRuleStringMatch
Returns a new instance of AuthzPolicyAuthzRuleStringMatch.
582 583 584 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 582 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contains ⇒ String
The input string must have the substring specified here. Note: empty contains
match is not allowed, please use regex instead. Examples: * abc matches
the value xyz.abc.def
Corresponds to the JSON property contains
552 553 554 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 552 def contains @contains end |
#exact ⇒ String
The input string must match exactly the string specified here. Examples: *
abc only matches the value abc.
Corresponds to the JSON property exact
558 559 560 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 558 def exact @exact end |
#ignore_case ⇒ Boolean Also known as: ignore_case?
If true, indicates the exact/prefix/suffix/contains matching should be case
insensitive. For example, the matcher data will match both input string
Data and data if set to true.
Corresponds to the JSON property ignoreCase
565 566 567 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 565 def ignore_case @ignore_case end |
#prefix ⇒ String
The input string must have the prefix specified here. Note: empty prefix is
not allowed, please use regex instead. Examples: * abc matches the value
abc.xyz
Corresponds to the JSON property prefix
573 574 575 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 573 def prefix @prefix end |
#suffix ⇒ String
The input string must have the suffix specified here. Note: empty prefix is
not allowed, please use regex instead. Examples: * abc matches the value
xyz.abc
Corresponds to the JSON property suffix
580 581 582 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 580 def suffix @suffix end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
587 588 589 590 591 592 593 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 587 def update!(**args) @contains = args[:contains] if args.key?(:contains) @exact = args[:exact] if args.key?(:exact) @ignore_case = args[:ignore_case] if args.key?(:ignore_case) @prefix = args[:prefix] if args.key?(:prefix) @suffix = args[:suffix] if args.key?(:suffix) end |