Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleToRequestOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Describes properties of one or more targets of a request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthzPolicyAuthzRuleToRequestOperation

Returns a new instance of AuthzPolicyAuthzRuleToRequestOperation.



677
678
679
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 677

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#header_setGoogle::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleToRequestOperationHeaderSet

Describes a set of HTTP headers to match against. Corresponds to the JSON property headerSet



643
644
645
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 643

def header_set
  @header_set
end

#hostsArray<Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleStringMatch>

Optional. A list of HTTP Hosts to match against. The match can be one of exact, prefix, suffix, or contains (substring match). Matches are always case sensitive unless the ignoreCase is set. Limited to 10 hosts per Authorization Policy. Corresponds to the JSON property hosts



651
652
653
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 651

def hosts
  @hosts
end

#mcpGoogle::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleToRequestOperationMcp

Describes a set of MCP protocol attributes to match against for a given MCP request. Corresponds to the JSON property mcp



657
658
659
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 657

def mcp
  @mcp
end

#methods_propArray<String>

Optional. A list of HTTP methods to match against. Each entry must be a valid HTTP method name (GET, PUT, POST, HEAD, PATCH, DELETE, OPTIONS). It only allows exact match and is always case sensitive. Limited to 10 methods per Authorization Policy. Corresponds to the JSON property methods

Returns:

  • (Array<String>)


665
666
667
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 665

def methods_prop
  @methods_prop
end

#pathsArray<Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleStringMatch>

Optional. A list of paths to match against. The match can be one of exact, prefix, suffix, or contains (substring match). Matches are always case sensitive unless the ignoreCase is set. Limited to 10 paths per Authorization Policy. Note that this path match includes the query parameters. For gRPC services, this should be a fully-qualified name of the form /package.service/ method. Corresponds to the JSON property paths



675
676
677
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 675

def paths
  @paths
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



682
683
684
685
686
687
688
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 682

def update!(**args)
  @header_set = args[:header_set] if args.key?(:header_set)
  @hosts = args[:hosts] if args.key?(:hosts)
  @mcp = args[:mcp] if args.key?(:mcp)
  @methods_prop = args[:methods_prop] if args.key?(:methods_prop)
  @paths = args[:paths] if args.key?(:paths)
end