Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleToRequestOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Describes properties of one or more targets of a request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthzPolicyAuthzRuleToRequestOperation

Returns a new instance of AuthzPolicyAuthzRuleToRequestOperation.



663
664
665
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 663

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#header_setGoogle::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleToRequestOperationHeaderSet

Describes a set of HTTP headers to match against. Corresponds to the JSON property headerSet



635
636
637
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 635

def header_set
  @header_set
end

#hostsArray<Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleStringMatch>

Optional. A list of HTTP Hosts to match against. The match can be one of exact, prefix, suffix, or contains (substring match). Matches are always case sensitive unless the ignoreCase is set. Limited to 10 hosts per Authorization Policy. Corresponds to the JSON property hosts



643
644
645
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 643

def hosts
  @hosts
end

#methods_propArray<String>

Optional. A list of HTTP methods to match against. Each entry must be a valid HTTP method name (GET, PUT, POST, HEAD, PATCH, DELETE, OPTIONS). It only allows exact match and is always case sensitive. Limited to 10 methods per Authorization Policy. Corresponds to the JSON property methods

Returns:

  • (Array<String>)


651
652
653
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 651

def methods_prop
  @methods_prop
end

#pathsArray<Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleStringMatch>

Optional. A list of paths to match against. The match can be one of exact, prefix, suffix, or contains (substring match). Matches are always case sensitive unless the ignoreCase is set. Limited to 10 paths per Authorization Policy. Note that this path match includes the query parameters. For gRPC services, this should be a fully-qualified name of the form /package.service/ method. Corresponds to the JSON property paths



661
662
663
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 661

def paths
  @paths
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



668
669
670
671
672
673
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 668

def update!(**args)
  @header_set = args[:header_set] if args.key?(:header_set)
  @hosts = args[:hosts] if args.key?(:hosts)
  @methods_prop = args[:methods_prop] if args.key?(:methods_prop)
  @paths = args[:paths] if args.key?(:paths)
end