Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleToRequestOperationHeaderSet
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleToRequestOperationHeaderSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Describes a set of HTTP headers to match against.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuthzPolicyAuthzRuleToRequestOperationHeaderSet
constructor
A new instance of AuthzPolicyAuthzRuleToRequestOperationHeaderSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuthzPolicyAuthzRuleToRequestOperationHeaderSet
Returns a new instance of AuthzPolicyAuthzRuleToRequestOperationHeaderSet.
704 705 706 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 704 def initialize(**args) update!(**args) end |
Instance Attribute Details
#headers ⇒ Array<Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleHeaderMatch>
Required. A list of headers to match against in http header. The match can be
one of exact, prefix, suffix, or contains (substring match). The match follows
AND semantics which means all the headers must match. Matches are always case
sensitive unless the ignoreCase is set. Limited to 10 headers per
Authorization Policy.
Corresponds to the JSON property headers
702 703 704 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 702 def headers @headers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
709 710 711 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 709 def update!(**args) @headers = args[:headers] if args.key?(:headers) end |