Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleToRequestOperationHeaderSet
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleToRequestOperationHeaderSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Describes a set of HTTP headers to match against.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuthzPolicyAuthzRuleToRequestOperationHeaderSet
constructor
A new instance of AuthzPolicyAuthzRuleToRequestOperationHeaderSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuthzPolicyAuthzRuleToRequestOperationHeaderSet
Returns a new instance of AuthzPolicyAuthzRuleToRequestOperationHeaderSet.
689 690 691 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 689 def initialize(**args) update!(**args) end |
Instance Attribute Details
#headers ⇒ Array<Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleHeaderMatch>
Required. A list of headers to match against in http header. The match can be
one of exact, prefix, suffix, or contains (substring match). The match follows
AND semantics which means all the headers must match. Matches are always case
sensitive unless the ignoreCase is set. Limited to 10 headers per
Authorization Policy.
Corresponds to the JSON property headers
687 688 689 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 687 def headers @headers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
694 695 696 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 694 def update!(**args) @headers = args[:headers] if args.key?(:headers) end |