Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleToRequestOperationMcpMethod

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Describes a set of MCP methods to match against.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthzPolicyAuthzRuleToRequestOperationMcpMethod

Returns a new instance of AuthzPolicyAuthzRuleToRequestOperationMcpMethod.



768
769
770
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. The MCP method to match against. Allowed values are as follows: 1. tools, prompts, resources - these will match against all sub methods under the respective methods. 2. prompts/list, tools/list, resources/list , resources/templates/list 3. prompts/get, tools/call, resources/ subscribe, resources/unsubscribe, resources/read Params cannot be specified for categories 1 and 2. Corresponds to the JSON property name

Returns:

  • (String)


758
759
760
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 758

def name
  @name
end

#paramsArray<Google::Apis::NetworksecurityV1beta1::AuthzPolicyAuthzRuleStringMatch>

Optional. A list of MCP method parameters to match against. The match can be one of exact, prefix, suffix, or contains (substring match). Matches are always case sensitive unless the ignoreCase is set. Limited to 10 MCP method parameters per Authorization Policy. Corresponds to the JSON property params



766
767
768
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 766

def params
  @params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



773
774
775
776
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 773

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
end