Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Specifies the set of targets to which this policy should be applied to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthzPolicyTarget

Returns a new instance of AuthzPolicyTarget.



869
870
871
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 869

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#load_balancing_schemeString

Optional. All gateways and forwarding rules referenced by this policy and extensions must share the same load balancing scheme. Required only when targeting forwarding rules. If targeting Secure Web Proxy, this field must be INTERNAL_MANAGED or not specified. Must not be specified when targeting Agent Gateway. Supported values: INTERNAL_MANAGED and EXTERNAL_MANAGED. For more information, refer to Backend services overview. Corresponds to the JSON property loadBalancingScheme

Returns:

  • (String)


861
862
863
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 861

def load_balancing_scheme
  @load_balancing_scheme
end

#resourcesArray<String>

Required. A list of references to the Forwarding Rules, Secure Web Proxy Gateways, or Agent Gateways on which this policy will be applied. Corresponds to the JSON property resources

Returns:

  • (Array<String>)


867
868
869
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 867

def resources
  @resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



874
875
876
877
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 874

def update!(**args)
  @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme)
  @resources = args[:resources] if args.key?(:resources)
end