Class: Google::Apis::NetworksecurityV1beta1::AuthzPolicyTarget
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::AuthzPolicyTarget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Specifies the set of targets to which this policy should be applied to.
Instance Attribute Summary collapse
-
#load_balancing_scheme ⇒ String
Required.
-
#resources ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuthzPolicyTarget
constructor
A new instance of AuthzPolicyTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuthzPolicyTarget
Returns a new instance of AuthzPolicyTarget.
787 788 789 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 787 def initialize(**args) update!(**args) end |
Instance Attribute Details
#load_balancing_scheme ⇒ String
Required. All gateways and forwarding rules referenced by this policy and
extensions must share the same load balancing scheme. Supported values:
INTERNAL_MANAGED and EXTERNAL_MANAGED. For more information, refer to
Backend services overview.
Corresponds to the JSON property loadBalancingScheme
779 780 781 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 779 def load_balancing_scheme @load_balancing_scheme end |
#resources ⇒ Array<String>
Required. A list of references to the Forwarding Rules on which this policy
will be applied.
Corresponds to the JSON property resources
785 786 787 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 785 def resources @resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
792 793 794 795 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 792 def update!(**args) @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme) @resources = args[:resources] if args.key?(:resources) end |