Class: Google::Apis::NetworksecurityV1beta1::BackendAuthenticationConfig
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::BackendAuthenticationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
BackendAuthenticationConfig message groups the TrustConfig together with other
settings that control how the load balancer authenticates, and expresses its
identity to, the backend: * trustConfig is the attached TrustConfig. *
wellKnownRoots indicates whether the load balance should trust backend server
certificates that are issued by public certificate authorities, in addition to
certificates trusted by the TrustConfig. * clientCertificate is a client
certificate that the load balancer uses to express its identity to the backend,
if the connection to the backend uses mTLS. You can attach the
BackendAuthenticationConfig to the load balancer's BackendService directly
determining how that BackendService negotiates TLS.
Instance Attribute Summary collapse
-
#client_certificate ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Set of label tags associated with the resource.
-
#name ⇒ String
Required.
-
#trust_config ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#well_known_roots ⇒ String
Well known roots to use for server certificate validation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendAuthenticationConfig
constructor
A new instance of BackendAuthenticationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendAuthenticationConfig
Returns a new instance of BackendAuthenticationConfig.
969 970 971 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 969 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_certificate ⇒ String
Optional. A reference to a certificatemanager.googleapis.com.Certificate
resource. This is a relative resource path following the form "projects/
project/locations/location/certificates/certificate". Used by a
BackendService to negotiate mTLS when the backend connection uses TLS and the
backend requests a client certificate. Must have a CLIENT_AUTH scope.
Corresponds to the JSON property clientCertificate
920 921 922 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 920 def client_certificate @client_certificate end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
925 926 927 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 925 def create_time @create_time end |
#description ⇒ String
Optional. Free-text description of the resource.
Corresponds to the JSON property description
930 931 932 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 930 def description @description end |
#etag ⇒ String
Output only. Etag of the resource.
Corresponds to the JSON property etag
935 936 937 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 935 def etag @etag end |
#labels ⇒ Hash<String,String>
Set of label tags associated with the resource.
Corresponds to the JSON property labels
940 941 942 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 940 def labels @labels end |
#name ⇒ String
Required. Name of the BackendAuthenticationConfig resource. It matches the
pattern projects/*/locations/location/backendAuthenticationConfigs/
backend_authentication_config`
Corresponds to the JSON propertyname`
947 948 949 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 947 def name @name end |
#trust_config ⇒ String
Optional. A reference to a TrustConfig resource from the certificatemanager.
googleapis.com namespace. This is a relative resource path following the form "
projects/project/locations/location/trustConfigs/trust_config". A
BackendService uses the chain of trust represented by this TrustConfig, if
specified, to validate the server certificates presented by the backend.
Required unless wellKnownRoots is set to PUBLIC_ROOTS.
Corresponds to the JSON property trustConfig
957 958 959 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 957 def trust_config @trust_config end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
962 963 964 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 962 def update_time @update_time end |
#well_known_roots ⇒ String
Well known roots to use for server certificate validation.
Corresponds to the JSON property wellKnownRoots
967 968 969 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 967 def well_known_roots @well_known_roots end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
974 975 976 977 978 979 980 981 982 983 984 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 974 def update!(**args) @client_certificate = args[:client_certificate] if args.key?(:client_certificate) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @trust_config = args[:trust_config] if args.key?(:trust_config) @update_time = args[:update_time] if args.key?(:update_time) @well_known_roots = args[:well_known_roots] if args.key?(:well_known_roots) end |