Class: Google::Apis::NetworksecurityV1beta1::BackendAuthenticationConfig
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::BackendAuthenticationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
BackendAuthenticationConfig message groups the TrustConfig together with other
settings that control how the load balancer authenticates, and expresses its
identity to, the backend: * trustConfig is the attached TrustConfig. *
wellKnownRoots indicates whether the load balance should trust backend server
certificates that are issued by public certificate authorities, in addition to
certificates trusted by the TrustConfig. * clientCertificate is a client
certificate that the load balancer uses to express its identity to the backend,
if the connection to the backend uses mTLS. You can attach the
BackendAuthenticationConfig to the load balancer's BackendService directly
determining how that BackendService negotiates TLS.
Instance Attribute Summary collapse
-
#client_certificate ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Set of label tags associated with the resource.
-
#name ⇒ String
Required.
-
#trust_config ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#well_known_roots ⇒ String
Well known roots to use for server certificate validation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendAuthenticationConfig
constructor
A new instance of BackendAuthenticationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendAuthenticationConfig
Returns a new instance of BackendAuthenticationConfig.
867 868 869 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_certificate ⇒ String
Optional. A reference to a certificatemanager.googleapis.com.Certificate
resource. This is a relative resource path following the form "projects/
project/locations/location/certificates/certificate". Used by a
BackendService to negotiate mTLS when the backend connection uses TLS and the
backend requests a client certificate. Must have a CLIENT_AUTH scope.
Corresponds to the JSON property clientCertificate
818 819 820 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 818 def client_certificate @client_certificate end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
823 824 825 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 823 def create_time @create_time end |
#description ⇒ String
Optional. Free-text description of the resource.
Corresponds to the JSON property description
828 829 830 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 828 def description @description end |
#etag ⇒ String
Output only. Etag of the resource.
Corresponds to the JSON property etag
833 834 835 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 833 def etag @etag end |
#labels ⇒ Hash<String,String>
Set of label tags associated with the resource.
Corresponds to the JSON property labels
838 839 840 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 838 def labels @labels end |
#name ⇒ String
Required. Name of the BackendAuthenticationConfig resource. It matches the
pattern projects/*/locations/location/backendAuthenticationConfigs/
backend_authentication_config`
Corresponds to the JSON propertyname`
845 846 847 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 845 def name @name end |
#trust_config ⇒ String
Optional. A reference to a TrustConfig resource from the certificatemanager.
googleapis.com namespace. This is a relative resource path following the form "
projects/project/locations/location/trustConfigs/trust_config". A
BackendService uses the chain of trust represented by this TrustConfig, if
specified, to validate the server certificates presented by the backend.
Required unless wellKnownRoots is set to PUBLIC_ROOTS.
Corresponds to the JSON property trustConfig
855 856 857 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 855 def trust_config @trust_config end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
860 861 862 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 860 def update_time @update_time end |
#well_known_roots ⇒ String
Well known roots to use for server certificate validation.
Corresponds to the JSON property wellKnownRoots
865 866 867 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 865 def well_known_roots @well_known_roots end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
872 873 874 875 876 877 878 879 880 881 882 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 872 def update!(**args) @client_certificate = args[:client_certificate] if args.key?(:client_certificate) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @trust_config = args[:trust_config] if args.key?(:trust_config) @update_time = args[:update_time] if args.key?(:update_time) @well_known_roots = args[:well_known_roots] if args.key?(:well_known_roots) end |