Class: Google::Apis::NetworksecurityV1beta1::CertificateProviderInstance
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::CertificateProviderInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Specification of a TLS certificate provider instance. Workloads may have one or more CertificateProvider instances (plugins) and one of them is enabled and configured by specifying this message. Workloads use the values from this message to locate and load the CertificateProvider instance configuration.
Instance Attribute Summary collapse
-
#plugin_instance ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CertificateProviderInstance
constructor
A new instance of CertificateProviderInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CertificateProviderInstance
Returns a new instance of CertificateProviderInstance.
912 913 914 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 912 def initialize(**args) update!(**args) end |
Instance Attribute Details
#plugin_instance ⇒ String
Required. Plugin instance name, used to locate and load CertificateProvider
instance configuration. Set to "google_cloud_private_spiffe" to use
Certificate Authority Service certificate provider instance.
Corresponds to the JSON property pluginInstance
910 911 912 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 910 def plugin_instance @plugin_instance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
917 918 919 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 917 def update!(**args) @plugin_instance = args[:plugin_instance] if args.key?(:plugin_instance) end |