Class: Google::Apis::NetworksecurityV1beta1::ClientTlsPolicy
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::ClientTlsPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
ClientTlsPolicy is a resource that specifies how a client should authenticate connections to backends of a service. This resource itself does not affect configuration unless it is attached to a backend service resource.
Instance Attribute Summary collapse
-
#client_certificate ⇒ Google::Apis::NetworksecurityV1beta1::GoogleCloudNetworksecurityV1beta1CertificateProvider
Specification of certificate provider.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Required.
-
#server_validation_ca ⇒ Array<Google::Apis::NetworksecurityV1beta1::ValidationCa>
Optional.
-
#sni ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClientTlsPolicy
constructor
A new instance of ClientTlsPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClientTlsPolicy
Returns a new instance of ClientTlsPolicy.
1055 1056 1057 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_certificate ⇒ Google::Apis::NetworksecurityV1beta1::GoogleCloudNetworksecurityV1beta1CertificateProvider
Specification of certificate provider. Defines the mechanism to obtain the
certificate and private key for peer to peer authentication.
Corresponds to the JSON property clientCertificate
1014 1015 1016 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1014 def client_certificate @client_certificate end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
1019 1020 1021 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1019 def create_time @create_time end |
#description ⇒ String
Optional. Free-text description of the resource.
Corresponds to the JSON property description
1024 1025 1026 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1024 def description @description end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the resource.
Corresponds to the JSON property labels
1029 1030 1031 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1029 def labels @labels end |
#name ⇒ String
Required. Name of the ClientTlsPolicy resource. It matches the pattern
projects/project/locations/location/clientTlsPolicies/client_tls_policy`
Corresponds to the JSON propertyname`
1035 1036 1037 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1035 def name @name end |
#server_validation_ca ⇒ Array<Google::Apis::NetworksecurityV1beta1::ValidationCa>
Optional. Defines the mechanism to obtain the Certificate Authority
certificate to validate the server certificate. If empty, client does not
validate the server certificate.
Corresponds to the JSON property serverValidationCa
1042 1043 1044 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1042 def server_validation_ca @server_validation_ca end |
#sni ⇒ String
Optional. Server Name Indication string to present to the server during TLS
handshake. E.g: "secure.example.com".
Corresponds to the JSON property sni
1048 1049 1050 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1048 def sni @sni end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
1053 1054 1055 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1053 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1060 def update!(**args) @client_certificate = args[:client_certificate] if args.key?(:client_certificate) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @server_validation_ca = args[:server_validation_ca] if args.key?(:server_validation_ca) @sni = args[:sni] if args.key?(:sni) @update_time = args[:update_time] if args.key?(:update_time) end |