Class: Google::Apis::NetworksecurityV1beta1::CloneAddressGroupItemsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Request used by the CloneAddressGroupItems method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloneAddressGroupItemsRequest

Returns a new instance of CloneAddressGroupItemsRequest.



1013
1014
1015
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1013

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


1006
1007
1008
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1006

def request_id
  @request_id
end

#source_address_groupString

Required. Source address group to clone items from. Corresponds to the JSON property sourceAddressGroup

Returns:

  • (String)


1011
1012
1013
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1011

def source_address_group
  @source_address_group
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1018
1019
1020
1021
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1018

def update!(**args)
  @request_id = args[:request_id] if args.key?(:request_id)
  @source_address_group = args[:source_address_group] if args.key?(:source_address_group)
end