Class: Google::Apis::NetworksecurityV1beta1::CustomInterceptProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

CustomInterceptProfile defines in-band integration behavior (intercept). It is used by firewall rules with an APPLY_SECURITY_PROFILE_GROUP action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomInterceptProfile

Returns a new instance of CustomInterceptProfile.



1036
1037
1038
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intercept_endpoint_groupString

Required. The target InterceptEndpointGroup. When a firewall rule with this security profile attached matches a packet, the packet will be intercepted to the location-local target in this group. Corresponds to the JSON property interceptEndpointGroup

Returns:

  • (String)


1034
1035
1036
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1034

def intercept_endpoint_group
  @intercept_endpoint_group
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1041
1042
1043
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1041

def update!(**args)
  @intercept_endpoint_group = args[:intercept_endpoint_group] if args.key?(:intercept_endpoint_group)
end