Class: Google::Apis::NetworksecurityV1beta1::CustomMirroringProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

CustomMirroringProfile defines out-of-band integration behavior (mirroring). It is used by mirroring rules with a MIRROR action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomMirroringProfile

Returns a new instance of CustomMirroringProfile.



1058
1059
1060
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1058

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mirroring_endpoint_groupString

Required. Immutable. The target MirroringEndpointGroup. When a mirroring rule with this security profile attached matches a packet, a replica will be mirrored to the location-local target in this group. Corresponds to the JSON property mirroringEndpointGroup

Returns:

  • (String)


1056
1057
1058
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1056

def mirroring_endpoint_group
  @mirroring_endpoint_group
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1063
1064
1065
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1063

def update!(**args)
  @mirroring_endpoint_group = args[:mirroring_endpoint_group] if args.key?(:mirroring_endpoint_group)
end