Class: Google::Apis::NetworksecurityV1beta1::DnsThreatDetector
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::DnsThreatDetector
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
A DNS threat detector sends DNS query logs to a provider that then analyzes
the logs to identify threat events in the DNS queries. By default, all VPC
networks in your projects are included. You can exclude specific networks by
supplying excluded_networks.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#excluded_networks ⇒ Array<String>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#provider ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DnsThreatDetector
constructor
A new instance of DnsThreatDetector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DnsThreatDetector
Returns a new instance of DnsThreatDetector.
1250 1251 1252 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1250 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Create time stamp.
Corresponds to the JSON property createTime
1221 1222 1223 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1221 def create_time @create_time end |
#excluded_networks ⇒ Array<String>
Optional. A list of network resource names which aren't monitored by this
DnsThreatDetector. Example: projects/PROJECT_ID/global/networks/NETWORK_NAME.
Corresponds to the JSON property excludedNetworks
1227 1228 1229 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1227 def excluded_networks @excluded_networks end |
#labels ⇒ Hash<String,String>
Optional. Any labels associated with the DnsThreatDetector, listed as key
value pairs.
Corresponds to the JSON property labels
1233 1234 1235 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1233 def labels @labels end |
#name ⇒ String
Immutable. Identifier. Name of the DnsThreatDetector resource.
Corresponds to the JSON property name
1238 1239 1240 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1238 def name @name end |
#provider ⇒ String
Required. The provider used for DNS threat analysis.
Corresponds to the JSON property provider
1243 1244 1245 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1243 def provider @provider end |
#update_time ⇒ String
Output only. Update time stamp.
Corresponds to the JSON property updateTime
1248 1249 1250 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1248 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1255 1256 1257 1258 1259 1260 1261 1262 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1255 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @excluded_networks = args[:excluded_networks] if args.key?(:excluded_networks) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @provider = args[:provider] if args.key?(:provider) @update_time = args[:update_time] if args.key?(:update_time) end |