Class: Google::Apis::NetworksecurityV1beta1::DnsThreatDetector
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::DnsThreatDetector
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
A DNS threat detector sends DNS query logs to a provider that then analyzes
the logs to identify threat events in the DNS queries. By default, all VPC
networks in your projects are included. You can exclude specific networks by
supplying excluded_networks.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#excluded_networks ⇒ Array<String>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#provider ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DnsThreatDetector
constructor
A new instance of DnsThreatDetector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DnsThreatDetector
Returns a new instance of DnsThreatDetector.
1230 1231 1232 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1230 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Create time stamp.
Corresponds to the JSON property createTime
1201 1202 1203 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1201 def create_time @create_time end |
#excluded_networks ⇒ Array<String>
Optional. A list of network resource names which aren't monitored by this
DnsThreatDetector. Example: projects/PROJECT_ID/global/networks/NETWORK_NAME.
Corresponds to the JSON property excludedNetworks
1207 1208 1209 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1207 def excluded_networks @excluded_networks end |
#labels ⇒ Hash<String,String>
Optional. Any labels associated with the DnsThreatDetector, listed as key
value pairs.
Corresponds to the JSON property labels
1213 1214 1215 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1213 def labels @labels end |
#name ⇒ String
Immutable. Identifier. Name of the DnsThreatDetector resource.
Corresponds to the JSON property name
1218 1219 1220 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1218 def name @name end |
#provider ⇒ String
Required. The provider used for DNS threat analysis.
Corresponds to the JSON property provider
1223 1224 1225 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1223 def provider @provider end |
#update_time ⇒ String
Output only. Update time stamp.
Corresponds to the JSON property updateTime
1228 1229 1230 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1228 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1235 1236 1237 1238 1239 1240 1241 1242 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1235 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @excluded_networks = args[:excluded_networks] if args.key?(:excluded_networks) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @provider = args[:provider] if args.key?(:provider) @update_time = args[:update_time] if args.key?(:update_time) end |