Class: Google::Apis::NetworksecurityV1beta1::DnsThreatDetector
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::DnsThreatDetector
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
A DNS threat detector sends DNS query logs to a provider that then analyzes
the logs to identify threat events in the DNS queries. By default, all VPC
networks in your projects are included. You can exclude specific networks by
supplying excluded_networks.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#excluded_networks ⇒ Array<String>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#provider ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DnsThreatDetector
constructor
A new instance of DnsThreatDetector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DnsThreatDetector
Returns a new instance of DnsThreatDetector.
1148 1149 1150 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1148 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Create time stamp.
Corresponds to the JSON property createTime
1119 1120 1121 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1119 def create_time @create_time end |
#excluded_networks ⇒ Array<String>
Optional. A list of network resource names which aren't monitored by this
DnsThreatDetector. Example: projects/PROJECT_ID/global/networks/NETWORK_NAME.
Corresponds to the JSON property excludedNetworks
1125 1126 1127 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1125 def excluded_networks @excluded_networks end |
#labels ⇒ Hash<String,String>
Optional. Any labels associated with the DnsThreatDetector, listed as key
value pairs.
Corresponds to the JSON property labels
1131 1132 1133 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1131 def labels @labels end |
#name ⇒ String
Immutable. Identifier. Name of the DnsThreatDetector resource.
Corresponds to the JSON property name
1136 1137 1138 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1136 def name @name end |
#provider ⇒ String
Required. The provider used for DNS threat analysis.
Corresponds to the JSON property provider
1141 1142 1143 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1141 def provider @provider end |
#update_time ⇒ String
Output only. Update time stamp.
Corresponds to the JSON property updateTime
1146 1147 1148 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1146 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1153 1154 1155 1156 1157 1158 1159 1160 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1153 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @excluded_networks = args[:excluded_networks] if args.key?(:excluded_networks) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @provider = args[:provider] if args.key?(:provider) @update_time = args[:update_time] if args.key?(:update_time) end |