Class: Google::Apis::NetworksecurityV1beta1::FirewallEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::FirewallEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Message describing Endpoint object.
Instance Attribute Summary collapse
-
#associated_networks ⇒ Array<String>
Output only.
-
#associations ⇒ Array<Google::Apis::NetworksecurityV1beta1::FirewallEndpointAssociationReference>
Output only.
-
#billing_project_id ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#endpoint_settings ⇒ Google::Apis::NetworksecurityV1beta1::FirewallEndpointEndpointSettings
Settings for the endpoint.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallEndpoint
constructor
A new instance of FirewallEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallEndpoint
Returns a new instance of FirewallEndpoint.
1416 1417 1418 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1416 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associated_networks ⇒ Array<String>
Output only. Deprecated: List of networks that are associated with this
endpoint in the local zone. This is a projection of the
FirewallEndpointAssociations pointing at this endpoint. A network will only
appear in this list after traffic routing is fully configured. Format:
projects/project/global/networks/name.
Corresponds to the JSON property associatedNetworks
1346 1347 1348 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1346 def associated_networks @associated_networks end |
#associations ⇒ Array<Google::Apis::NetworksecurityV1beta1::FirewallEndpointAssociationReference>
Output only. List of FirewallEndpointAssociations that are associated to this
endpoint. An association will only appear in this list after traffic routing
is fully configured.
Corresponds to the JSON property associations
1353 1354 1355 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1353 def associations @associations end |
#billing_project_id ⇒ String
Optional. Project to charge for the deployed firewall endpoint. This field
must be specified when creating the endpoint in the organization scope, and
should be omitted otherwise.
Corresponds to the JSON property billingProjectId
1360 1361 1362 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1360 def billing_project_id @billing_project_id end |
#create_time ⇒ String
Output only. Create time stamp.
Corresponds to the JSON property createTime
1365 1366 1367 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1365 def create_time @create_time end |
#description ⇒ String
Optional. Description of the firewall endpoint. Max length 2048 characters.
Corresponds to the JSON property description
1370 1371 1372 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1370 def description @description end |
#endpoint_settings ⇒ Google::Apis::NetworksecurityV1beta1::FirewallEndpointEndpointSettings
Settings for the endpoint.
Corresponds to the JSON property endpointSettings
1375 1376 1377 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1375 def endpoint_settings @endpoint_settings end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs
Corresponds to the JSON property labels
1380 1381 1382 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1380 def labels @labels end |
#name ⇒ String
Immutable. Identifier. Name of resource.
Corresponds to the JSON property name
1385 1386 1387 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1385 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Whether reconciling is in progress, recommended per https://
google.aip.dev/128.
Corresponds to the JSON property reconciling
1391 1392 1393 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1391 def reconciling @reconciling end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzi
1397 1398 1399 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1397 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
1403 1404 1405 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1403 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. Current state of the endpoint.
Corresponds to the JSON property state
1409 1410 1411 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1409 def state @state end |
#update_time ⇒ String
Output only. Update time stamp
Corresponds to the JSON property updateTime
1414 1415 1416 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1414 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1421 def update!(**args) @associated_networks = args[:associated_networks] if args.key?(:associated_networks) @associations = args[:associations] if args.key?(:associations) @billing_project_id = args[:billing_project_id] if args.key?(:billing_project_id) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @endpoint_settings = args[:endpoint_settings] if args.key?(:endpoint_settings) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |