Class: Google::Apis::NetworksecurityV1beta1::FirewallEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Message describing Endpoint object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallEndpoint

Returns a new instance of FirewallEndpoint.



1395
1396
1397
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1395

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associated_networksArray<String>

Output only. List of networks that are associated with this endpoint in the local zone. This is a projection of the FirewallEndpointAssociations pointing at this endpoint. A network will only appear in this list after traffic routing is fully configured. Format: projects/project/global/networks/name. Corresponds to the JSON property associatedNetworks

Returns:

  • (Array<String>)


1325
1326
1327
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1325

def associated_networks
  @associated_networks
end

#associationsArray<Google::Apis::NetworksecurityV1beta1::FirewallEndpointAssociationReference>

Output only. List of FirewallEndpointAssociations that are associated to this endpoint. An association will only appear in this list after traffic routing is fully configured. Corresponds to the JSON property associations



1332
1333
1334
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1332

def associations
  @associations
end

#billing_project_idString

Optional. Project to charge for the deployed firewall endpoint. This field must be specified when creating the endpoint in the organization scope, and should be omitted otherwise. Corresponds to the JSON property billingProjectId

Returns:

  • (String)


1339
1340
1341
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1339

def billing_project_id
  @billing_project_id
end

#create_timeString

Output only. Create time stamp. Corresponds to the JSON property createTime

Returns:

  • (String)


1344
1345
1346
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1344

def create_time
  @create_time
end

#descriptionString

Optional. Description of the firewall endpoint. Max length 2048 characters. Corresponds to the JSON property description

Returns:

  • (String)


1349
1350
1351
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1349

def description
  @description
end

#endpoint_settingsGoogle::Apis::NetworksecurityV1beta1::FirewallEndpointEndpointSettings

Settings for the endpoint. Corresponds to the JSON property endpointSettings



1354
1355
1356
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1354

def endpoint_settings
  @endpoint_settings
end

#labelsHash<String,String>

Optional. Labels as key value pairs Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1359
1360
1361
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1359

def labels
  @labels
end

#nameString

Immutable. Identifier. Name of resource. Corresponds to the JSON property name

Returns:

  • (String)


1364
1365
1366
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1364

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. Whether reconciling is in progress, recommended per https:// google.aip.dev/128. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


1370
1371
1372
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1370

def reconciling
  @reconciling
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


1376
1377
1378
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1376

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


1382
1383
1384
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1382

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. Current state of the endpoint. Corresponds to the JSON property state

Returns:

  • (String)


1388
1389
1390
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1388

def state
  @state
end

#update_timeString

Output only. Update time stamp Corresponds to the JSON property updateTime

Returns:

  • (String)


1393
1394
1395
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1393

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1400

def update!(**args)
  @associated_networks = args[:associated_networks] if args.key?(:associated_networks)
  @associations = args[:associations] if args.key?(:associations)
  @billing_project_id = args[:billing_project_id] if args.key?(:billing_project_id)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @endpoint_settings = args[:endpoint_settings] if args.key?(:endpoint_settings)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end