Class: Google::Apis::NetworksecurityV1beta1::FirewallEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::FirewallEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Message describing Endpoint object.
Instance Attribute Summary collapse
-
#associated_networks ⇒ Array<String>
Output only.
-
#associations ⇒ Array<Google::Apis::NetworksecurityV1beta1::FirewallEndpointAssociationReference>
Output only.
-
#billing_project_id ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#endpoint_settings ⇒ Google::Apis::NetworksecurityV1beta1::FirewallEndpointEndpointSettings
Settings for the endpoint.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallEndpoint
constructor
A new instance of FirewallEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallEndpoint
Returns a new instance of FirewallEndpoint.
1395 1396 1397 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associated_networks ⇒ Array<String>
Output only. List of networks that are associated with this endpoint in the
local zone. This is a projection of the FirewallEndpointAssociations pointing
at this endpoint. A network will only appear in this list after traffic
routing is fully configured. Format: projects/project/global/networks/name.
Corresponds to the JSON property associatedNetworks
1325 1326 1327 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1325 def associated_networks @associated_networks end |
#associations ⇒ Array<Google::Apis::NetworksecurityV1beta1::FirewallEndpointAssociationReference>
Output only. List of FirewallEndpointAssociations that are associated to this
endpoint. An association will only appear in this list after traffic routing
is fully configured.
Corresponds to the JSON property associations
1332 1333 1334 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1332 def associations @associations end |
#billing_project_id ⇒ String
Optional. Project to charge for the deployed firewall endpoint. This field
must be specified when creating the endpoint in the organization scope, and
should be omitted otherwise.
Corresponds to the JSON property billingProjectId
1339 1340 1341 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1339 def billing_project_id @billing_project_id end |
#create_time ⇒ String
Output only. Create time stamp.
Corresponds to the JSON property createTime
1344 1345 1346 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1344 def create_time @create_time end |
#description ⇒ String
Optional. Description of the firewall endpoint. Max length 2048 characters.
Corresponds to the JSON property description
1349 1350 1351 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1349 def description @description end |
#endpoint_settings ⇒ Google::Apis::NetworksecurityV1beta1::FirewallEndpointEndpointSettings
Settings for the endpoint.
Corresponds to the JSON property endpointSettings
1354 1355 1356 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1354 def endpoint_settings @endpoint_settings end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs
Corresponds to the JSON property labels
1359 1360 1361 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1359 def labels @labels end |
#name ⇒ String
Immutable. Identifier. Name of resource.
Corresponds to the JSON property name
1364 1365 1366 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1364 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Whether reconciling is in progress, recommended per https://
google.aip.dev/128.
Corresponds to the JSON property reconciling
1370 1371 1372 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1370 def reconciling @reconciling end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzi
1376 1377 1378 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1376 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
1382 1383 1384 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1382 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. Current state of the endpoint.
Corresponds to the JSON property state
1388 1389 1390 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1388 def state @state end |
#update_time ⇒ String
Output only. Update time stamp
Corresponds to the JSON property updateTime
1393 1394 1395 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1393 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1400 def update!(**args) @associated_networks = args[:associated_networks] if args.key?(:associated_networks) @associations = args[:associations] if args.key?(:associations) @billing_project_id = args[:billing_project_id] if args.key?(:billing_project_id) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @endpoint_settings = args[:endpoint_settings] if args.key?(:endpoint_settings) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |