Class: Google::Apis::NetworksecurityV1beta1::FirewallEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::FirewallEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Message describing Endpoint object.
Instance Attribute Summary collapse
-
#associated_networks ⇒ Array<String>
Output only.
-
#associations ⇒ Array<Google::Apis::NetworksecurityV1beta1::FirewallEndpointAssociationReference>
Output only.
-
#billing_project_id ⇒ String
Required.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#endpoint_settings ⇒ Google::Apis::NetworksecurityV1beta1::FirewallEndpointEndpointSettings
Settings for the endpoint.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallEndpoint
constructor
A new instance of FirewallEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallEndpoint
Returns a new instance of FirewallEndpoint.
1311 1312 1313 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1311 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associated_networks ⇒ Array<String>
Output only. List of networks that are associated with this endpoint in the
local zone. This is a projection of the FirewallEndpointAssociations pointing
at this endpoint. A network will only appear in this list after traffic
routing is fully configured. Format: projects/project/global/networks/name.
Corresponds to the JSON property associatedNetworks
1243 1244 1245 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1243 def associated_networks @associated_networks end |
#associations ⇒ Array<Google::Apis::NetworksecurityV1beta1::FirewallEndpointAssociationReference>
Output only. List of FirewallEndpointAssociations that are associated to this
endpoint. An association will only appear in this list after traffic routing
is fully configured.
Corresponds to the JSON property associations
1250 1251 1252 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1250 def associations @associations end |
#billing_project_id ⇒ String
Required. Project to bill on endpoint uptime usage.
Corresponds to the JSON property billingProjectId
1255 1256 1257 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1255 def billing_project_id @billing_project_id end |
#create_time ⇒ String
Output only. Create time stamp.
Corresponds to the JSON property createTime
1260 1261 1262 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1260 def create_time @create_time end |
#description ⇒ String
Optional. Description of the firewall endpoint. Max length 2048 characters.
Corresponds to the JSON property description
1265 1266 1267 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1265 def description @description end |
#endpoint_settings ⇒ Google::Apis::NetworksecurityV1beta1::FirewallEndpointEndpointSettings
Settings for the endpoint.
Corresponds to the JSON property endpointSettings
1270 1271 1272 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1270 def endpoint_settings @endpoint_settings end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs
Corresponds to the JSON property labels
1275 1276 1277 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1275 def labels @labels end |
#name ⇒ String
Immutable. Identifier. Name of resource.
Corresponds to the JSON property name
1280 1281 1282 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1280 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Whether reconciling is in progress, recommended per https://
google.aip.dev/128.
Corresponds to the JSON property reconciling
1286 1287 1288 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1286 def reconciling @reconciling end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzi
1292 1293 1294 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1292 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
1298 1299 1300 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1298 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. Current state of the endpoint.
Corresponds to the JSON property state
1304 1305 1306 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1304 def state @state end |
#update_time ⇒ String
Output only. Update time stamp
Corresponds to the JSON property updateTime
1309 1310 1311 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1309 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1316 def update!(**args) @associated_networks = args[:associated_networks] if args.key?(:associated_networks) @associations = args[:associations] if args.key?(:associations) @billing_project_id = args[:billing_project_id] if args.key?(:billing_project_id) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @endpoint_settings = args[:endpoint_settings] if args.key?(:endpoint_settings) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |