Class: Google::Apis::NetworksecurityV1beta1::FirewallEndpointWildfireSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Settings for WildFire analysis.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallEndpointWildfireSettings

Returns a new instance of FirewallEndpointWildfireSettings.



1623
1624
1625
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Optional. Indicates whether WildFire analysis is enabled. Default value is false. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


1594
1595
1596
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1594

def enabled
  @enabled
end

#wildfire_inline_cloud_analysis_settingsGoogle::Apis::NetworksecurityV1beta1::FirewallEndpointWildfireSettingsWildfireInlineCloudAnalysisSettings

Settings for WildFire inline cloud analysis. Corresponds to the JSON property wildfireInlineCloudAnalysisSettings



1600
1601
1602
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1600

def wildfire_inline_cloud_analysis_settings
  @wildfire_inline_cloud_analysis_settings
end

#wildfire_realtime_lookup_durationString

Optional. Duration in milliseconds on a file being held while the WildFire real time signature cloud performs a signature lookup. Value between 1 to 5000 is valid. Default value is 1000. Corresponds to the JSON property wildfireRealtimeLookupDuration

Returns:

  • (String)


1607
1608
1609
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1607

def wildfire_realtime_lookup_duration
  @wildfire_realtime_lookup_duration
end

#wildfire_realtime_lookup_timeout_actionString

Optional. Action to take on WildFire real time signature lookup timeout. Default value is ALLOW. Corresponds to the JSON property wildfireRealtimeLookupTimeoutAction

Returns:

  • (String)


1613
1614
1615
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1613

def wildfire_realtime_lookup_timeout_action
  @wildfire_realtime_lookup_timeout_action
end

#wildfire_regionString

Optional. The region where WildFire analysis will be performed. PAN supports regions: https://docs.paloaltonetworks.com/advanced-wildfire/administration/ advanced-wildfire-overview/advanced-wildfire-deployments/advanced-wildfire- global-cloud Corresponds to the JSON property wildfireRegion

Returns:

  • (String)


1621
1622
1623
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1621

def wildfire_region
  @wildfire_region
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1628
1629
1630
1631
1632
1633
1634
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1628

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @wildfire_inline_cloud_analysis_settings = args[:wildfire_inline_cloud_analysis_settings] if args.key?(:wildfire_inline_cloud_analysis_settings)
  @wildfire_realtime_lookup_duration = args[:wildfire_realtime_lookup_duration] if args.key?(:wildfire_realtime_lookup_duration)
  @wildfire_realtime_lookup_timeout_action = args[:wildfire_realtime_lookup_timeout_action] if args.key?(:wildfire_realtime_lookup_timeout_action)
  @wildfire_region = args[:wildfire_region] if args.key?(:wildfire_region)
end