Class: Google::Apis::NetworksecurityV1beta1::GatewaySecurityPolicyRule
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::GatewaySecurityPolicyRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
The GatewaySecurityPolicyRule resource is in a nested collection within a GatewaySecurityPolicy and represents a traffic matching condition and associated action to perform.
Instance Attribute Summary collapse
-
#application_matcher ⇒ String
Optional.
-
#basic_profile ⇒ String
Required.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#enabled ⇒ Boolean
(also: #enabled?)
Required.
-
#name ⇒ String
Required.
-
#priority ⇒ Fixnum
Required.
-
#session_matcher ⇒ String
Required.
-
#tls_inspection_enabled ⇒ Boolean
(also: #tls_inspection_enabled?)
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GatewaySecurityPolicyRule
constructor
A new instance of GatewaySecurityPolicyRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GatewaySecurityPolicyRule
Returns a new instance of GatewaySecurityPolicyRule.
1674 1675 1676 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1674 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application_matcher ⇒ String
Optional. CEL expression for matching on L7/application level criteria.
Corresponds to the JSON property applicationMatcher
1621 1622 1623 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1621 def application_matcher @application_matcher end |
#basic_profile ⇒ String
Required. Profile which tells what the primitive action should be.
Corresponds to the JSON property basicProfile
1626 1627 1628 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1626 def basic_profile @basic_profile end |
#create_time ⇒ String
Output only. Time when the rule was created.
Corresponds to the JSON property createTime
1631 1632 1633 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1631 def create_time @create_time end |
#description ⇒ String
Optional. Free-text description of the resource.
Corresponds to the JSON property description
1636 1637 1638 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1636 def description @description end |
#enabled ⇒ Boolean Also known as: enabled?
Required. Whether the rule is enforced.
Corresponds to the JSON property enabled
1641 1642 1643 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1641 def enabled @enabled end |
#name ⇒ String
Required. Immutable. Name of the resource. ame is the full resource name so
projects/project/locations/location/gatewaySecurityPolicies/
gateway_security_policy/rules/rule rule should match the pattern: (^a-z?$).
Corresponds to the JSON property name
1650 1651 1652 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1650 def name @name end |
#priority ⇒ Fixnum
Required. Priority of the rule. Lower number corresponds to higher precedence.
Corresponds to the JSON property priority
1655 1656 1657 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1655 def priority @priority end |
#session_matcher ⇒ String
Required. CEL expression for matching on session criteria.
Corresponds to the JSON property sessionMatcher
1660 1661 1662 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1660 def session_matcher @session_matcher end |
#tls_inspection_enabled ⇒ Boolean Also known as: tls_inspection_enabled?
Optional. Flag to enable TLS inspection of traffic matching on , can only be
true if the parent GatewaySecurityPolicy references a TLSInspectionConfig.
Corresponds to the JSON property tlsInspectionEnabled
1666 1667 1668 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1666 def tls_inspection_enabled @tls_inspection_enabled end |
#update_time ⇒ String
Output only. Time when the rule was updated.
Corresponds to the JSON property updateTime
1672 1673 1674 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1672 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 1679 def update!(**args) @application_matcher = args[:application_matcher] if args.key?(:application_matcher) @basic_profile = args[:basic_profile] if args.key?(:basic_profile) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @enabled = args[:enabled] if args.key?(:enabled) @name = args[:name] if args.key?(:name) @priority = args[:priority] if args.key?(:priority) @session_matcher = args[:session_matcher] if args.key?(:session_matcher) @tls_inspection_enabled = args[:tls_inspection_enabled] if args.key?(:tls_inspection_enabled) @update_time = args[:update_time] if args.key?(:update_time) end |