Class: Google::Apis::NetworksecurityV1beta1::InterceptDeploymentGroup
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::InterceptDeploymentGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
A deployment group aggregates many zonal intercept backends (deployments) into a single global intercept service. Consumers can connect this service using an endpoint group.
Instance Attribute Summary collapse
-
#connected_endpoint_groups ⇒ Array<Google::Apis::NetworksecurityV1beta1::InterceptDeploymentGroupConnectedEndpointGroup>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#locations ⇒ Array<Google::Apis::NetworksecurityV1beta1::InterceptLocation>
Output only.
-
#name ⇒ String
Immutable.
-
#nested_deployments ⇒ Array<Google::Apis::NetworksecurityV1beta1::InterceptDeploymentGroupDeployment>
Output only.
-
#network ⇒ String
Required.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterceptDeploymentGroup
constructor
A new instance of InterceptDeploymentGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterceptDeploymentGroup
Returns a new instance of InterceptDeploymentGroup.
2401 2402 2403 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connected_endpoint_groups ⇒ Array<Google::Apis::NetworksecurityV1beta1::InterceptDeploymentGroupConnectedEndpointGroup>
Output only. The list of endpoint groups that are connected to this resource.
Corresponds to the JSON property connectedEndpointGroups
2336 2337 2338 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2336 def connected_endpoint_groups @connected_endpoint_groups end |
#create_time ⇒ String
Output only. The timestamp when the resource was created. See https://google.
aip.dev/148#timestamps.
Corresponds to the JSON property createTime
2342 2343 2344 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2342 def create_time @create_time end |
#description ⇒ String
Optional. User-provided description of the deployment group. Used as
additional context for the deployment group.
Corresponds to the JSON property description
2348 2349 2350 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2348 def description @description end |
#labels ⇒ Hash<String,String>
Optional. Labels are key/value pairs that help to organize and filter
resources.
Corresponds to the JSON property labels
2354 2355 2356 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2354 def labels @labels end |
#locations ⇒ Array<Google::Apis::NetworksecurityV1beta1::InterceptLocation>
Output only. The list of locations where the deployment group is present.
Corresponds to the JSON property locations
2359 2360 2361 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2359 def locations @locations end |
#name ⇒ String
Immutable. Identifier. The resource name of this deployment group, for example:
projects/123456789/locations/global/interceptDeploymentGroups/my-dg. See
https://google.aip.dev/122 for more details.
Corresponds to the JSON property name
2366 2367 2368 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2366 def name @name end |
#nested_deployments ⇒ Array<Google::Apis::NetworksecurityV1beta1::InterceptDeploymentGroupDeployment>
Output only. The list of Intercept Deployments that belong to this group.
Corresponds to the JSON property nestedDeployments
2371 2372 2373 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2371 def nested_deployments @nested_deployments end |
#network ⇒ String
Required. Immutable. The network that will be used for all child deployments,
for example: projects/project/global/networks/network`. See https://
google.aip.dev/124.
Corresponds to the JSON propertynetwork`
2378 2379 2380 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2378 def network @network end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. The current state of the resource does not match the user's
intended state, and the system is working to reconcile them. This is part of
the normal operation (e.g. adding a new deployment to the group) See https://
google.aip.dev/128.
Corresponds to the JSON property reconciling
2386 2387 2388 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2386 def reconciling @reconciling end |
#state ⇒ String
Output only. The current state of the deployment group. See https://google.aip.
dev/216.
Corresponds to the JSON property state
2393 2394 2395 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2393 def state @state end |
#update_time ⇒ String
Output only. The timestamp when the resource was most recently updated. See
https://google.aip.dev/148#timestamps.
Corresponds to the JSON property updateTime
2399 2400 2401 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2399 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2406 def update!(**args) @connected_endpoint_groups = args[:connected_endpoint_groups] if args.key?(:connected_endpoint_groups) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @locations = args[:locations] if args.key?(:locations) @name = args[:name] if args.key?(:name) @nested_deployments = args[:nested_deployments] if args.key?(:nested_deployments) @network = args[:network] if args.key?(:network) @reconciling = args[:reconciling] if args.key?(:reconciling) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |