Class: Google::Apis::NetworksecurityV1beta1::InterceptDeploymentGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

A deployment group aggregates many zonal intercept backends (deployments) into a single global intercept service. Consumers can connect this service using an endpoint group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterceptDeploymentGroup

Returns a new instance of InterceptDeploymentGroup.



2292
2293
2294
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2292

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connected_endpoint_groupsArray<Google::Apis::NetworksecurityV1beta1::InterceptDeploymentGroupConnectedEndpointGroup>

Output only. The list of endpoint groups that are connected to this resource. Corresponds to the JSON property connectedEndpointGroups



2227
2228
2229
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2227

def connected_endpoint_groups
  @connected_endpoint_groups
end

#create_timeString

Output only. The timestamp when the resource was created. See https://google. aip.dev/148#timestamps. Corresponds to the JSON property createTime

Returns:

  • (String)


2233
2234
2235
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2233

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description of the deployment group. Used as additional context for the deployment group. Corresponds to the JSON property description

Returns:

  • (String)


2239
2240
2241
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2239

def description
  @description
end

#labelsHash<String,String>

Optional. Labels are key/value pairs that help to organize and filter resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2245
2246
2247
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2245

def labels
  @labels
end

#locationsArray<Google::Apis::NetworksecurityV1beta1::InterceptLocation>

Output only. The list of locations where the deployment group is present. Corresponds to the JSON property locations



2250
2251
2252
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2250

def locations
  @locations
end

#nameString

Immutable. Identifier. The resource name of this deployment group, for example: projects/123456789/locations/global/interceptDeploymentGroups/my-dg. See https://google.aip.dev/122 for more details. Corresponds to the JSON property name

Returns:

  • (String)


2257
2258
2259
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2257

def name
  @name
end

#nested_deploymentsArray<Google::Apis::NetworksecurityV1beta1::InterceptDeploymentGroupDeployment>

Output only. The list of Intercept Deployments that belong to this group. Corresponds to the JSON property nestedDeployments



2262
2263
2264
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2262

def nested_deployments
  @nested_deployments
end

#networkString

Required. Immutable. The network that will be used for all child deployments, for example: projects/project/global/networks/network`. See https:// google.aip.dev/124. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


2269
2270
2271
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2269

def network
  @network
end

#reconcilingBoolean Also known as: reconciling?

Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new deployment to the group) See https:// google.aip.dev/128. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


2277
2278
2279
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2277

def reconciling
  @reconciling
end

#stateString

Output only. The current state of the deployment group. See https://google.aip. dev/216. Corresponds to the JSON property state

Returns:

  • (String)


2284
2285
2286
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2284

def state
  @state
end

#update_timeString

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps. Corresponds to the JSON property updateTime

Returns:

  • (String)


2290
2291
2292
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2290

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2297

def update!(**args)
  @connected_endpoint_groups = args[:connected_endpoint_groups] if args.key?(:connected_endpoint_groups)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @locations = args[:locations] if args.key?(:locations)
  @name = args[:name] if args.key?(:name)
  @nested_deployments = args[:nested_deployments] if args.key?(:nested_deployments)
  @network = args[:network] if args.key?(:network)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end