Class: Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroup
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
An endpoint group is a consumer frontend for a deployment group (backend). In order to configure intercept for a network, consumers must create: - An association between their network and the endpoint group. - A security profile that points to the endpoint group. - A firewall rule that references the security profile (group).
Instance Attribute Summary collapse
-
#associations ⇒ Array<Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroupAssociationDetails>
Output only.
-
#connected_deployment_group ⇒ Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroupConnectedDeploymentGroup
The endpoint group's view of a connected deployment group.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#intercept_deployment_group ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterceptEndpointGroup
constructor
A new instance of InterceptEndpointGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterceptEndpointGroup
Returns a new instance of InterceptEndpointGroup.
2430 2431 2432 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2430 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associations ⇒ Array<Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroupAssociationDetails>
Output only. List of associations to this endpoint group.
Corresponds to the JSON property associations
2370 2371 2372 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2370 def associations @associations end |
#connected_deployment_group ⇒ Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroupConnectedDeploymentGroup
The endpoint group's view of a connected deployment group.
Corresponds to the JSON property connectedDeploymentGroup
2375 2376 2377 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2375 def connected_deployment_group @connected_deployment_group end |
#create_time ⇒ String
Output only. The timestamp when the resource was created. See https://google.
aip.dev/148#timestamps.
Corresponds to the JSON property createTime
2381 2382 2383 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2381 def create_time @create_time end |
#description ⇒ String
Optional. User-provided description of the endpoint group. Used as additional
context for the endpoint group.
Corresponds to the JSON property description
2387 2388 2389 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2387 def description @description end |
#intercept_deployment_group ⇒ String
Required. Immutable. The deployment group that this endpoint group is
connected to, for example: projects/123456789/locations/global/
interceptDeploymentGroups/my-dg. See https://google.aip.dev/124.
Corresponds to the JSON property interceptDeploymentGroup
2394 2395 2396 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2394 def intercept_deployment_group @intercept_deployment_group end |
#labels ⇒ Hash<String,String>
Optional. Labels are key/value pairs that help to organize and filter
resources.
Corresponds to the JSON property labels
2400 2401 2402 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2400 def labels @labels end |
#name ⇒ String
Immutable. Identifier. The resource name of this endpoint group, for example:
projects/123456789/locations/global/interceptEndpointGroups/my-eg. See https:/
/google.aip.dev/122 for more details.
Corresponds to the JSON property name
2407 2408 2409 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2407 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. The current state of the resource does not match the user's
intended state, and the system is working to reconcile them. This is part of
the normal operation (e.g. adding a new association to the group). See https://
google.aip.dev/128.
Corresponds to the JSON property reconciling
2415 2416 2417 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2415 def reconciling @reconciling end |
#state ⇒ String
Output only. The current state of the endpoint group. See https://google.aip.
dev/216.
Corresponds to the JSON property state
2422 2423 2424 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2422 def state @state end |
#update_time ⇒ String
Output only. The timestamp when the resource was most recently updated. See
https://google.aip.dev/148#timestamps.
Corresponds to the JSON property updateTime
2428 2429 2430 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2428 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2435 def update!(**args) @associations = args[:associations] if args.key?(:associations) @connected_deployment_group = args[:connected_deployment_group] if args.key?(:connected_deployment_group) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @intercept_deployment_group = args[:intercept_deployment_group] if args.key?(:intercept_deployment_group) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |