Class: Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

An endpoint group is a consumer frontend for a deployment group (backend). In order to configure intercept for a network, consumers must create: - An association between their network and the endpoint group. - A security profile that points to the endpoint group. - A firewall rule that references the security profile (group).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterceptEndpointGroup

Returns a new instance of InterceptEndpointGroup.



2325
2326
2327
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2325

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associationsArray<Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroupAssociationDetails>

Output only. List of associations to this endpoint group. Corresponds to the JSON property associations



2265
2266
2267
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2265

def associations
  @associations
end

#connected_deployment_groupGoogle::Apis::NetworksecurityV1beta1::InterceptEndpointGroupConnectedDeploymentGroup

The endpoint group's view of a connected deployment group. Corresponds to the JSON property connectedDeploymentGroup



2270
2271
2272
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2270

def connected_deployment_group
  @connected_deployment_group
end

#create_timeString

Output only. The timestamp when the resource was created. See https://google. aip.dev/148#timestamps. Corresponds to the JSON property createTime

Returns:

  • (String)


2276
2277
2278
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2276

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description of the endpoint group. Used as additional context for the endpoint group. Corresponds to the JSON property description

Returns:

  • (String)


2282
2283
2284
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2282

def description
  @description
end

#intercept_deployment_groupString

Required. Immutable. The deployment group that this endpoint group is connected to, for example: projects/123456789/locations/global/ interceptDeploymentGroups/my-dg. See https://google.aip.dev/124. Corresponds to the JSON property interceptDeploymentGroup

Returns:

  • (String)


2289
2290
2291
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2289

def intercept_deployment_group
  @intercept_deployment_group
end

#labelsHash<String,String>

Optional. Labels are key/value pairs that help to organize and filter resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2295
2296
2297
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2295

def labels
  @labels
end

#nameString

Immutable. Identifier. The resource name of this endpoint group, for example: projects/123456789/locations/global/interceptEndpointGroups/my-eg. See https:/ /google.aip.dev/122 for more details. Corresponds to the JSON property name

Returns:

  • (String)


2302
2303
2304
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2302

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new association to the group). See https:// google.aip.dev/128. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


2310
2311
2312
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2310

def reconciling
  @reconciling
end

#stateString

Output only. The current state of the endpoint group. See https://google.aip. dev/216. Corresponds to the JSON property state

Returns:

  • (String)


2317
2318
2319
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2317

def state
  @state
end

#update_timeString

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps. Corresponds to the JSON property updateTime

Returns:

  • (String)


2323
2324
2325
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2323

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2330

def update!(**args)
  @associations = args[:associations] if args.key?(:associations)
  @connected_deployment_group = args[:connected_deployment_group] if args.key?(:connected_deployment_group)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @intercept_deployment_group = args[:intercept_deployment_group] if args.key?(:intercept_deployment_group)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end