Class: Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroupAssociation
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroupAssociation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
An endpoint group association represents a link between a network and an endpoint group in the organization. Creating an association creates the networking infrastructure linking the network to the endpoint group, but does not enable intercept by itself. To enable intercept, the user must also create a network firewall policy containing intercept rules and associate it with the network.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#intercept_endpoint_group ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#locations ⇒ Array<Google::Apis::NetworksecurityV1beta1::InterceptLocation>
Output only.
-
#locations_details ⇒ Array<Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroupAssociationLocationDetails>
Output only.
-
#name ⇒ String
Immutable.
-
#network ⇒ String
Required.
-
#network_cookie ⇒ Fixnum
Output only.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterceptEndpointGroupAssociation
constructor
A new instance of InterceptEndpointGroupAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterceptEndpointGroupAssociation
Returns a new instance of InterceptEndpointGroupAssociation.
2641 2642 2643 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2641 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created. See https://google.
aip.dev/148#timestamps.
Corresponds to the JSON property createTime
2572 2573 2574 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2572 def create_time @create_time end |
#intercept_endpoint_group ⇒ String
Required. Immutable. The endpoint group that this association is connected to,
for example: projects/123456789/locations/global/interceptEndpointGroups/my-
eg. See https://google.aip.dev/124.
Corresponds to the JSON property interceptEndpointGroup
2579 2580 2581 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2579 def intercept_endpoint_group @intercept_endpoint_group end |
#labels ⇒ Hash<String,String>
Optional. Labels are key/value pairs that help to organize and filter
resources.
Corresponds to the JSON property labels
2585 2586 2587 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2585 def labels @labels end |
#locations ⇒ Array<Google::Apis::NetworksecurityV1beta1::InterceptLocation>
Output only. The list of locations where the association is configured. This
information is retrieved from the linked endpoint group.
Corresponds to the JSON property locations
2591 2592 2593 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2591 def locations @locations end |
#locations_details ⇒ Array<Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroupAssociationLocationDetails>
Output only. The list of locations where the association is present. This
information is retrieved from the linked endpoint group, and not configured as
part of the association itself.
Corresponds to the JSON property locationsDetails
2598 2599 2600 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2598 def locations_details @locations_details end |
#name ⇒ String
Immutable. Identifier. The resource name of this endpoint group association,
for example: projects/123456789/locations/global/
interceptEndpointGroupAssociations/my-eg-association. See https://google.aip.
dev/122 for more details.
Corresponds to the JSON property name
2606 2607 2608 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2606 def name @name end |
#network ⇒ String
Required. Immutable. The VPC network that is associated. for example:
projects/123456789/global/networks/my-network. See https://google.aip.dev/124.
Corresponds to the JSON property network
2612 2613 2614 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2612 def network @network end |
#network_cookie ⇒ Fixnum
Output only. Identifier used by the data-path. See the NSI GENEVE format for
more details: https://docs.cloud.google.com/network-security-integration/docs/
understand-geneve#network_id
Corresponds to the JSON property networkCookie
2619 2620 2621 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2619 def @network_cookie end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. The current state of the resource does not match the user's
intended state, and the system is working to reconcile them. This part of the
normal operation (e.g. adding a new location to the target deployment group).
See https://google.aip.dev/128.
Corresponds to the JSON property reconciling
2627 2628 2629 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2627 def reconciling @reconciling end |
#state ⇒ String
Output only. Current state of the endpoint group association.
Corresponds to the JSON property state
2633 2634 2635 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2633 def state @state end |
#update_time ⇒ String
Output only. The timestamp when the resource was most recently updated. See
https://google.aip.dev/148#timestamps.
Corresponds to the JSON property updateTime
2639 2640 2641 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2639 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 2656 2657 2658 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2646 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @intercept_endpoint_group = args[:intercept_endpoint_group] if args.key?(:intercept_endpoint_group) @labels = args[:labels] if args.key?(:labels) @locations = args[:locations] if args.key?(:locations) @locations_details = args[:locations_details] if args.key?(:locations_details) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @network_cookie = args[:network_cookie] if args.key?(:network_cookie) @reconciling = args[:reconciling] if args.key?(:reconciling) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |