Class: Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroupAssociationLocationDetails
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::InterceptEndpointGroupAssociationLocationDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Contains details about the state of an association in a specific cloud location.
Instance Attribute Summary collapse
-
#location ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterceptEndpointGroupAssociationLocationDetails
constructor
A new instance of InterceptEndpointGroupAssociationLocationDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterceptEndpointGroupAssociationLocationDetails
Returns a new instance of InterceptEndpointGroupAssociationLocationDetails.
2487 2488 2489 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2487 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location ⇒ String
Output only. The cloud location, e.g. "us-central1-a" or "asia-south1".
Corresponds to the JSON property location
2480 2481 2482 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2480 def location @location end |
#state ⇒ String
Output only. The current state of the association in this location.
Corresponds to the JSON property state
2485 2486 2487 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2485 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2492 2493 2494 2495 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2492 def update!(**args) @location = args[:location] if args.key?(:location) @state = args[:state] if args.key?(:state) end |