Class: Google::Apis::NetworksecurityV1beta1::ListBackendAuthenticationConfigsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Response returned by the ListBackendAuthenticationConfigs method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListBackendAuthenticationConfigsResponse

Returns a new instance of ListBackendAuthenticationConfigsResponse.



2720
2721
2722
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2720

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_authentication_configsArray<Google::Apis::NetworksecurityV1beta1::BackendAuthenticationConfig>

List of BackendAuthenticationConfig resources. Corresponds to the JSON property backendAuthenticationConfigs



2706
2707
2708
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2706

def backend_authentication_configs
  @backend_authentication_configs
end

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2713
2714
2715
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2713

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2718
2719
2720
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2718

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2725
2726
2727
2728
2729
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 2725

def update!(**args)
  @backend_authentication_configs = args[:backend_authentication_configs] if args.key?(:backend_authentication_configs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end