Class: Google::Apis::NetworksecurityV1beta1::ListSacRealmsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::ListSacRealmsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Response for ListSACRealms method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#sac_realms ⇒ Array<Google::Apis::NetworksecurityV1beta1::SacRealm>
The list of SACRealms.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSacRealmsResponse
constructor
A new instance of ListSacRealmsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSacRealmsResponse
Returns a new instance of ListSacRealmsResponse.
3478 3479 3480 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3478 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
3466 3467 3468 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3466 def next_page_token @next_page_token end |
#sac_realms ⇒ Array<Google::Apis::NetworksecurityV1beta1::SacRealm>
The list of SACRealms.
Corresponds to the JSON property sacRealms
3471 3472 3473 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3471 def sac_realms @sac_realms end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
3476 3477 3478 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3476 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3483 3484 3485 3486 3487 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3483 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @sac_realms = args[:sac_realms] if args.key?(:sac_realms) @unreachable = args[:unreachable] if args.key?(:unreachable) end |