Class: Google::Apis::NetworksecurityV1beta1::ListSacRealmsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::ListSacRealmsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Response for ListSACRealms method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#sac_realms ⇒ Array<Google::Apis::NetworksecurityV1beta1::SacRealm>
The list of SACRealms.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSacRealmsResponse
constructor
A new instance of ListSacRealmsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSacRealmsResponse
Returns a new instance of ListSacRealmsResponse.
3368 3369 3370 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3368 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
3356 3357 3358 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3356 def next_page_token @next_page_token end |
#sac_realms ⇒ Array<Google::Apis::NetworksecurityV1beta1::SacRealm>
The list of SACRealms.
Corresponds to the JSON property sacRealms
3361 3362 3363 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3361 def sac_realms @sac_realms end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
3366 3367 3368 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3366 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3373 3374 3375 3376 3377 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3373 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @sac_realms = args[:sac_realms] if args.key?(:sac_realms) @unreachable = args[:unreachable] if args.key?(:unreachable) end |