Class: Google::Apis::NetworksecurityV1beta1::ListServerTlsPoliciesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Response returned by the ListServerTlsPolicies method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListServerTlsPoliciesResponse

Returns a new instance of ListServerTlsPoliciesResponse.



3344
3345
3346
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3330
3331
3332
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3330

def next_page_token
  @next_page_token
end

#server_tls_policiesArray<Google::Apis::NetworksecurityV1beta1::ServerTlsPolicy>

List of ServerTlsPolicy resources. Corresponds to the JSON property serverTlsPolicies



3335
3336
3337
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3335

def server_tls_policies
  @server_tls_policies
end

#unreachableArray<String>

Unreachable resources. Populated when the request opts into return_partial_success and reading across collections e.g. when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3342
3343
3344
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3342

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3349
3350
3351
3352
3353
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3349

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @server_tls_policies = args[:server_tls_policies] if args.key?(:server_tls_policies)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end