Class: Google::Apis::NetworksecurityV1beta1::MirroringDeployment
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::MirroringDeployment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
A deployment represents a zonal mirroring backend ready to accept GENEVE- encapsulated replica traffic, e.g. a zonal instance group fronted by an internal passthrough load balancer. Deployments are always part of a global deployment group which represents a global mirroring service.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#forwarding_rule ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#mirroring_deployment_group ⇒ String
Required.
-
#name ⇒ String
Immutable.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MirroringDeployment
constructor
A new instance of MirroringDeployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MirroringDeployment
Returns a new instance of MirroringDeployment.
3688 3689 3690 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3688 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created. See https://google.
aip.dev/148#timestamps.
Corresponds to the JSON property createTime
3632 3633 3634 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3632 def create_time @create_time end |
#description ⇒ String
Optional. User-provided description of the deployment. Used as additional
context for the deployment.
Corresponds to the JSON property description
3638 3639 3640 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3638 def description @description end |
#forwarding_rule ⇒ String
Required. Immutable. The regional forwarding rule that fronts the mirroring
collectors, for example: projects/123456789/regions/us-central1/
forwardingRules/my-rule. See https://google.aip.dev/124.
Corresponds to the JSON property forwardingRule
3645 3646 3647 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3645 def forwarding_rule @forwarding_rule end |
#labels ⇒ Hash<String,String>
Optional. Labels are key/value pairs that help to organize and filter
resources.
Corresponds to the JSON property labels
3651 3652 3653 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3651 def labels @labels end |
#mirroring_deployment_group ⇒ String
Required. Immutable. The deployment group that this deployment is a part of,
for example: projects/123456789/locations/global/mirroringDeploymentGroups/my-
dg. See https://google.aip.dev/124.
Corresponds to the JSON property mirroringDeploymentGroup
3658 3659 3660 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3658 def mirroring_deployment_group @mirroring_deployment_group end |
#name ⇒ String
Immutable. Identifier. The resource name of this deployment, for example:
projects/123456789/locations/us-central1-a/mirroringDeployments/my-dep. See
https://google.aip.dev/122 for more details.
Corresponds to the JSON property name
3665 3666 3667 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3665 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. The current state of the resource does not match the user's
intended state, and the system is working to reconcile them. This part of the
normal operation (e.g. linking a new association to the parent group). See
https://google.aip.dev/128.
Corresponds to the JSON property reconciling
3673 3674 3675 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3673 def reconciling @reconciling end |
#state ⇒ String
Output only. The current state of the deployment. See https://google.aip.dev/
216.
Corresponds to the JSON property state
3680 3681 3682 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3680 def state @state end |
#update_time ⇒ String
Output only. The timestamp when the resource was most recently updated. See
https://google.aip.dev/148#timestamps.
Corresponds to the JSON property updateTime
3686 3687 3688 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3686 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3693 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @labels = args[:labels] if args.key?(:labels) @mirroring_deployment_group = args[:mirroring_deployment_group] if args.key?(:mirroring_deployment_group) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |