Class: Google::Apis::NetworksecurityV1beta1::MirroringDeploymentGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

A deployment group aggregates many zonal mirroring backends (deployments) into a single global mirroring service. Consumers can connect this service using an endpoint group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MirroringDeploymentGroup

Returns a new instance of MirroringDeploymentGroup.



3921
3922
3923
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connected_endpoint_groupsArray<Google::Apis::NetworksecurityV1beta1::MirroringDeploymentGroupConnectedEndpointGroup>

Output only. The list of endpoint groups that are connected to this resource. Corresponds to the JSON property connectedEndpointGroups



3856
3857
3858
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3856

def connected_endpoint_groups
  @connected_endpoint_groups
end

#create_timeString

Output only. The timestamp when the resource was created. See https://google. aip.dev/148#timestamps. Corresponds to the JSON property createTime

Returns:

  • (String)


3862
3863
3864
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3862

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description of the deployment group. Used as additional context for the deployment group. Corresponds to the JSON property description

Returns:

  • (String)


3868
3869
3870
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3868

def description
  @description
end

#labelsHash<String,String>

Optional. Labels are key/value pairs that help to organize and filter resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3874
3875
3876
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3874

def labels
  @labels
end

#locationsArray<Google::Apis::NetworksecurityV1beta1::MirroringLocation>

Output only. The list of locations where the deployment group is present. Corresponds to the JSON property locations



3879
3880
3881
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3879

def locations
  @locations
end

#nameString

Immutable. Identifier. The resource name of this deployment group, for example: projects/123456789/locations/global/mirroringDeploymentGroups/my-dg. See https://google.aip.dev/122 for more details. Corresponds to the JSON property name

Returns:

  • (String)


3886
3887
3888
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3886

def name
  @name
end

#nested_deploymentsArray<Google::Apis::NetworksecurityV1beta1::MirroringDeploymentGroupDeployment>

Output only. The list of Mirroring Deployments that belong to this group. Corresponds to the JSON property nestedDeployments



3891
3892
3893
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3891

def nested_deployments
  @nested_deployments
end

#networkString

Required. Immutable. The network that will be used for all child deployments, for example: projects/project/global/networks/network`. See https:// google.aip.dev/124. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


3898
3899
3900
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3898

def network
  @network
end

#reconcilingBoolean Also known as: reconciling?

Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new deployment to the group) See https:// google.aip.dev/128. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


3906
3907
3908
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3906

def reconciling
  @reconciling
end

#stateString

Output only. The current state of the deployment group. See https://google.aip. dev/216. Corresponds to the JSON property state

Returns:

  • (String)


3913
3914
3915
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3913

def state
  @state
end

#update_timeString

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps. Corresponds to the JSON property updateTime

Returns:

  • (String)


3919
3920
3921
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3919

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3926
3927
3928
3929
3930
3931
3932
3933
3934
3935
3936
3937
3938
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3926

def update!(**args)
  @connected_endpoint_groups = args[:connected_endpoint_groups] if args.key?(:connected_endpoint_groups)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @locations = args[:locations] if args.key?(:locations)
  @name = args[:name] if args.key?(:name)
  @nested_deployments = args[:nested_deployments] if args.key?(:nested_deployments)
  @network = args[:network] if args.key?(:network)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end