Class: Google::Apis::NetworksecurityV1beta1::MirroringDeploymentGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

A deployment group aggregates many zonal mirroring backends (deployments) into a single global mirroring service. Consumers can connect this service using an endpoint group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MirroringDeploymentGroup

Returns a new instance of MirroringDeploymentGroup.



3780
3781
3782
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3780

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connected_endpoint_groupsArray<Google::Apis::NetworksecurityV1beta1::MirroringDeploymentGroupConnectedEndpointGroup>

Output only. The list of endpoint groups that are connected to this resource. Corresponds to the JSON property connectedEndpointGroups



3715
3716
3717
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3715

def connected_endpoint_groups
  @connected_endpoint_groups
end

#create_timeString

Output only. The timestamp when the resource was created. See https://google. aip.dev/148#timestamps. Corresponds to the JSON property createTime

Returns:

  • (String)


3721
3722
3723
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3721

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description of the deployment group. Used as additional context for the deployment group. Corresponds to the JSON property description

Returns:

  • (String)


3727
3728
3729
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3727

def description
  @description
end

#labelsHash<String,String>

Optional. Labels are key/value pairs that help to organize and filter resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3733
3734
3735
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3733

def labels
  @labels
end

#locationsArray<Google::Apis::NetworksecurityV1beta1::MirroringLocation>

Output only. The list of locations where the deployment group is present. Corresponds to the JSON property locations



3738
3739
3740
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3738

def locations
  @locations
end

#nameString

Immutable. Identifier. The resource name of this deployment group, for example: projects/123456789/locations/global/mirroringDeploymentGroups/my-dg. See https://google.aip.dev/122 for more details. Corresponds to the JSON property name

Returns:

  • (String)


3745
3746
3747
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3745

def name
  @name
end

#nested_deploymentsArray<Google::Apis::NetworksecurityV1beta1::MirroringDeploymentGroupDeployment>

Output only. The list of Mirroring Deployments that belong to this group. Corresponds to the JSON property nestedDeployments



3750
3751
3752
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3750

def nested_deployments
  @nested_deployments
end

#networkString

Required. Immutable. The network that will be used for all child deployments, for example: projects/project/global/networks/network`. See https:// google.aip.dev/124. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


3757
3758
3759
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3757

def network
  @network
end

#reconcilingBoolean Also known as: reconciling?

Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new deployment to the group) See https:// google.aip.dev/128. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


3765
3766
3767
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3765

def reconciling
  @reconciling
end

#stateString

Output only. The current state of the deployment group. See https://google.aip. dev/216. Corresponds to the JSON property state

Returns:

  • (String)


3772
3773
3774
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3772

def state
  @state
end

#update_timeString

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps. Corresponds to the JSON property updateTime

Returns:

  • (String)


3778
3779
3780
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3778

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3785

def update!(**args)
  @connected_endpoint_groups = args[:connected_endpoint_groups] if args.key?(:connected_endpoint_groups)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @locations = args[:locations] if args.key?(:locations)
  @name = args[:name] if args.key?(:name)
  @nested_deployments = args[:nested_deployments] if args.key?(:nested_deployments)
  @network = args[:network] if args.key?(:network)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end