Class: Google::Apis::NetworksecurityV1beta1::MirroringDeploymentGroup
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::MirroringDeploymentGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
A deployment group aggregates many zonal mirroring backends (deployments) into a single global mirroring service. Consumers can connect this service using an endpoint group.
Instance Attribute Summary collapse
-
#connected_endpoint_groups ⇒ Array<Google::Apis::NetworksecurityV1beta1::MirroringDeploymentGroupConnectedEndpointGroup>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#locations ⇒ Array<Google::Apis::NetworksecurityV1beta1::MirroringLocation>
Output only.
-
#name ⇒ String
Immutable.
-
#nested_deployments ⇒ Array<Google::Apis::NetworksecurityV1beta1::MirroringDeploymentGroupDeployment>
Output only.
-
#network ⇒ String
Required.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MirroringDeploymentGroup
constructor
A new instance of MirroringDeploymentGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MirroringDeploymentGroup
Returns a new instance of MirroringDeploymentGroup.
3667 3668 3669 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connected_endpoint_groups ⇒ Array<Google::Apis::NetworksecurityV1beta1::MirroringDeploymentGroupConnectedEndpointGroup>
Output only. The list of endpoint groups that are connected to this resource.
Corresponds to the JSON property connectedEndpointGroups
3602 3603 3604 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3602 def connected_endpoint_groups @connected_endpoint_groups end |
#create_time ⇒ String
Output only. The timestamp when the resource was created. See https://google.
aip.dev/148#timestamps.
Corresponds to the JSON property createTime
3608 3609 3610 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3608 def create_time @create_time end |
#description ⇒ String
Optional. User-provided description of the deployment group. Used as
additional context for the deployment group.
Corresponds to the JSON property description
3614 3615 3616 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3614 def description @description end |
#labels ⇒ Hash<String,String>
Optional. Labels are key/value pairs that help to organize and filter
resources.
Corresponds to the JSON property labels
3620 3621 3622 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3620 def labels @labels end |
#locations ⇒ Array<Google::Apis::NetworksecurityV1beta1::MirroringLocation>
Output only. The list of locations where the deployment group is present.
Corresponds to the JSON property locations
3625 3626 3627 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3625 def locations @locations end |
#name ⇒ String
Immutable. Identifier. The resource name of this deployment group, for example:
projects/123456789/locations/global/mirroringDeploymentGroups/my-dg. See
https://google.aip.dev/122 for more details.
Corresponds to the JSON property name
3632 3633 3634 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3632 def name @name end |
#nested_deployments ⇒ Array<Google::Apis::NetworksecurityV1beta1::MirroringDeploymentGroupDeployment>
Output only. The list of Mirroring Deployments that belong to this group.
Corresponds to the JSON property nestedDeployments
3637 3638 3639 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3637 def nested_deployments @nested_deployments end |
#network ⇒ String
Required. Immutable. The network that will be used for all child deployments,
for example: projects/project/global/networks/network`. See https://
google.aip.dev/124.
Corresponds to the JSON propertynetwork`
3644 3645 3646 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3644 def network @network end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. The current state of the resource does not match the user's
intended state, and the system is working to reconcile them. This is part of
the normal operation (e.g. adding a new deployment to the group) See https://
google.aip.dev/128.
Corresponds to the JSON property reconciling
3652 3653 3654 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3652 def reconciling @reconciling end |
#state ⇒ String
Output only. The current state of the deployment group. See https://google.aip.
dev/216.
Corresponds to the JSON property state
3659 3660 3661 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3659 def state @state end |
#update_time ⇒ String
Output only. The timestamp when the resource was most recently updated. See
https://google.aip.dev/148#timestamps.
Corresponds to the JSON property updateTime
3665 3666 3667 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3665 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3672 3673 3674 3675 3676 3677 3678 3679 3680 3681 3682 3683 3684 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3672 def update!(**args) @connected_endpoint_groups = args[:connected_endpoint_groups] if args.key?(:connected_endpoint_groups) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @locations = args[:locations] if args.key?(:locations) @name = args[:name] if args.key?(:name) @nested_deployments = args[:nested_deployments] if args.key?(:nested_deployments) @network = args[:network] if args.key?(:network) @reconciling = args[:reconciling] if args.key?(:reconciling) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |