Class: Google::Apis::NetworksecurityV1beta1::MirroringEndpointGroup
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::MirroringEndpointGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
An endpoint group is a consumer frontend for a deployment group (backend). In order to configure mirroring for a network, consumers must create: - An association between their network and the endpoint group. - A security profile that points to the endpoint group. - A mirroring rule that references the security profile (group).
Instance Attribute Summary collapse
-
#associations ⇒ Array<Google::Apis::NetworksecurityV1beta1::MirroringEndpointGroupAssociationDetails>
Output only.
-
#connected_deployment_groups ⇒ Array<Google::Apis::NetworksecurityV1beta1::MirroringEndpointGroupConnectedDeploymentGroup>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#mirroring_deployment_group ⇒ String
Immutable.
-
#name ⇒ String
Immutable.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MirroringEndpointGroup
constructor
A new instance of MirroringEndpointGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MirroringEndpointGroup
Returns a new instance of MirroringEndpointGroup.
3904 3905 3906 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3904 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associations ⇒ Array<Google::Apis::NetworksecurityV1beta1::MirroringEndpointGroupAssociationDetails>
Output only. List of associations to this endpoint group.
Corresponds to the JSON property associations
3837 3838 3839 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3837 def associations @associations end |
#connected_deployment_groups ⇒ Array<Google::Apis::NetworksecurityV1beta1::MirroringEndpointGroupConnectedDeploymentGroup>
Output only. List of details about the connected deployment groups to this
endpoint group.
Corresponds to the JSON property connectedDeploymentGroups
3843 3844 3845 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3843 def connected_deployment_groups @connected_deployment_groups end |
#create_time ⇒ String
Output only. The timestamp when the resource was created. See https://google.
aip.dev/148#timestamps.
Corresponds to the JSON property createTime
3849 3850 3851 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3849 def create_time @create_time end |
#description ⇒ String
Optional. User-provided description of the endpoint group. Used as additional
context for the endpoint group.
Corresponds to the JSON property description
3855 3856 3857 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3855 def description @description end |
#labels ⇒ Hash<String,String>
Optional. Labels are key/value pairs that help to organize and filter
resources.
Corresponds to the JSON property labels
3861 3862 3863 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3861 def labels @labels end |
#mirroring_deployment_group ⇒ String
Immutable. The deployment group that this DIRECT endpoint group is connected
to, for example: projects/123456789/locations/global/
mirroringDeploymentGroups/my-dg. See https://google.aip.dev/124.
Corresponds to the JSON property mirroringDeploymentGroup
3868 3869 3870 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3868 def mirroring_deployment_group @mirroring_deployment_group end |
#name ⇒ String
Immutable. Identifier. The resource name of this endpoint group, for example:
projects/123456789/locations/global/mirroringEndpointGroups/my-eg. See https:/
/google.aip.dev/122 for more details.
Corresponds to the JSON property name
3875 3876 3877 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3875 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. The current state of the resource does not match the user's
intended state, and the system is working to reconcile them. This is part of
the normal operation (e.g. adding a new association to the group). See https://
google.aip.dev/128.
Corresponds to the JSON property reconciling
3883 3884 3885 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3883 def reconciling @reconciling end |
#state ⇒ String
Output only. The current state of the endpoint group. See https://google.aip.
dev/216.
Corresponds to the JSON property state
3890 3891 3892 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3890 def state @state end |
#type ⇒ String
Immutable. The type of the endpoint group. If left unspecified, defaults to
DIRECT.
Corresponds to the JSON property type
3896 3897 3898 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3896 def type @type end |
#update_time ⇒ String
Output only. The timestamp when the resource was most recently updated. See
https://google.aip.dev/148#timestamps.
Corresponds to the JSON property updateTime
3902 3903 3904 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3902 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 3920 3921 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3909 def update!(**args) @associations = args[:associations] if args.key?(:associations) @connected_deployment_groups = args[:connected_deployment_groups] if args.key?(:connected_deployment_groups) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @mirroring_deployment_group = args[:mirroring_deployment_group] if args.key?(:mirroring_deployment_group) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |