Class: Google::Apis::NetworksecurityV1beta1::MirroringEndpointGroupAssociation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

An endpoint group association represents a link between a network and an endpoint group in the organization. Creating an association creates the networking infrastructure linking the network to the endpoint group, but does not enable mirroring by itself. To enable mirroring, the user must also create a network firewall policy containing mirroring rules and associate it with the network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MirroringEndpointGroupAssociation

Returns a new instance of MirroringEndpointGroupAssociation.



4020
4021
4022
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4020

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. See https://google. aip.dev/148#timestamps. Corresponds to the JSON property createTime

Returns:

  • (String)


3958
3959
3960
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3958

def create_time
  @create_time
end

#labelsHash<String,String>

Optional. Labels are key/value pairs that help to organize and filter resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3964
3965
3966
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3964

def labels
  @labels
end

#locationsArray<Google::Apis::NetworksecurityV1beta1::MirroringLocation>

Output only. The list of locations where the association is configured. This information is retrieved from the linked endpoint group. Corresponds to the JSON property locations



3970
3971
3972
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3970

def locations
  @locations
end

#locations_detailsArray<Google::Apis::NetworksecurityV1beta1::MirroringEndpointGroupAssociationLocationDetails>

Output only. The list of locations where the association is present. This information is retrieved from the linked endpoint group, and not configured as part of the association itself. Corresponds to the JSON property locationsDetails



3977
3978
3979
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3977

def locations_details
  @locations_details
end

#mirroring_endpoint_groupString

Immutable. The endpoint group that this association is connected to, for example: projects/123456789/locations/global/mirroringEndpointGroups/my-eg. See https://google.aip.dev/124. Corresponds to the JSON property mirroringEndpointGroup

Returns:

  • (String)


3984
3985
3986
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3984

def mirroring_endpoint_group
  @mirroring_endpoint_group
end

#nameString

Immutable. Identifier. The resource name of this endpoint group association, for example: projects/123456789/locations/global/ mirroringEndpointGroupAssociations/my-eg-association. See https://google.aip. dev/122 for more details. Corresponds to the JSON property name

Returns:

  • (String)


3992
3993
3994
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3992

def name
  @name
end

#networkString

Immutable. The VPC network that is associated. for example: projects/ 123456789/global/networks/my-network. See https://google.aip.dev/124. Corresponds to the JSON property network

Returns:

  • (String)


3998
3999
4000
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3998

def network
  @network
end

#reconcilingBoolean Also known as: reconciling?

Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This part of the normal operation (e.g. adding a new location to the target deployment group). See https://google.aip.dev/128. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


4006
4007
4008
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4006

def reconciling
  @reconciling
end

#stateString

Output only. Current state of the endpoint group association. Corresponds to the JSON property state

Returns:

  • (String)


4012
4013
4014
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4012

def state
  @state
end

#update_timeString

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps. Corresponds to the JSON property updateTime

Returns:

  • (String)


4018
4019
4020
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4018

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4025

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @labels = args[:labels] if args.key?(:labels)
  @locations = args[:locations] if args.key?(:locations)
  @locations_details = args[:locations_details] if args.key?(:locations_details)
  @mirroring_endpoint_group = args[:mirroring_endpoint_group] if args.key?(:mirroring_endpoint_group)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end