Class: Google::Apis::NetworksecurityV1beta1::MtlsPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Specification of the MTLSPolicy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MtlsPolicy

Returns a new instance of MtlsPolicy.



3496
3497
3498
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3496

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_validation_caArray<Google::Apis::NetworksecurityV1beta1::ValidationCa>

Required if the policy is to be used with Traffic Director. For Application Load Balancers it must be empty. Defines the mechanism to obtain the Certificate Authority certificate to validate the client certificate. Corresponds to the JSON property clientValidationCa



3478
3479
3480
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3478

def client_validation_ca
  @client_validation_ca
end

#client_validation_modeString

When the client presents an invalid certificate or no certificate to the load balancer, the client_validation_mode specifies how the client connection is handled. Required if the policy is to be used with the Application Load Balancers. For Traffic Director it must be empty. Corresponds to the JSON property clientValidationMode

Returns:

  • (String)


3486
3487
3488
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3486

def client_validation_mode
  @client_validation_mode
end

#client_validation_trust_configString

Reference to the TrustConfig from certificatemanager.googleapis.com namespace. If specified, the chain validation will be performed against certificates configured in the given TrustConfig. Allowed only if the policy is to be used with Application Load Balancers. Corresponds to the JSON property clientValidationTrustConfig

Returns:

  • (String)


3494
3495
3496
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3494

def client_validation_trust_config
  @client_validation_trust_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3501
3502
3503
3504
3505
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 3501

def update!(**args)
  @client_validation_ca = args[:client_validation_ca] if args.key?(:client_validation_ca)
  @client_validation_mode = args[:client_validation_mode] if args.key?(:client_validation_mode)
  @client_validation_trust_config = args[:client_validation_trust_config] if args.key?(:client_validation_trust_config)
end