Class: Google::Apis::NetworksecurityV1beta1::Operation
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::Operation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
This resource represents a long-running operation that is the result of a network API call.
Instance Attribute Summary collapse
-
#done ⇒ Boolean
(also: #done?)
If the value is
false, it means the operation is still in progress. -
#error ⇒ Google::Apis::NetworksecurityV1beta1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#metadata ⇒ Hash<String,Object>
Service-specific metadata associated with the operation.
-
#name ⇒ String
The server-assigned name, which is only unique within the same service that originally returns it.
-
#response ⇒ Hash<String,Object>
The normal, successful response of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Operation
constructor
A new instance of Operation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Operation
Returns a new instance of Operation.
4348 4349 4350 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4348 def initialize(**args) update!(**args) end |
Instance Attribute Details
#done ⇒ Boolean Also known as: done?
If the value is false, it means the operation is still in progress. If true
, the operation is completed, and either error or response is available.
Corresponds to the JSON property done
4309 4310 4311 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4309 def done @done end |
#error ⇒ Google::Apis::NetworksecurityV1beta1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
4320 4321 4322 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4320 def error @error end |
#metadata ⇒ Hash<String,Object>
Service-specific metadata associated with the operation. It typically contains
progress information and common metadata such as create time. Some services
might not provide such metadata. Any method that returns a long-running
operation should document the metadata type, if any.
Corresponds to the JSON property metadata
4328 4329 4330 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4328 def @metadata end |
#name ⇒ String
The server-assigned name, which is only unique within the same service that
originally returns it. If you use the default HTTP mapping, the name should
be a resource name ending with operations/unique_id`.
Corresponds to the JSON propertyname`
4335 4336 4337 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4335 def name @name end |
#response ⇒ Hash<String,Object>
The normal, successful response of the operation. If the original method
returns no data on success, such as Delete, the response is google.protobuf.
Empty. If the original method is standard Get/Create/Update, the
response should be the resource. For other methods, the response should have
the type XxxResponse, where Xxx is the original method name. For example,
if the original method name is TakeSnapshot(), the inferred response type is
TakeSnapshotResponse.
Corresponds to the JSON property response
4346 4347 4348 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4346 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4353 4354 4355 4356 4357 4358 4359 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4353 def update!(**args) @done = args[:done] if args.key?(:done) @error = args[:error] if args.key?(:error) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @response = args[:response] if args.key?(:response) end |