Class: Google::Apis::NetworksecurityV1beta1::RemoveAddressGroupItemsRequest
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::RemoveAddressGroupItemsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Request used by the RemoveAddressGroupItems method.
Instance Attribute Summary collapse
-
#items ⇒ Array<String>
Required.
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveAddressGroupItemsRequest
constructor
A new instance of RemoveAddressGroupItemsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveAddressGroupItemsRequest
Returns a new instance of RemoveAddressGroupItemsRequest.
4444 4445 4446 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Array<String>
Required. List of items to remove.
Corresponds to the JSON property items
4428 4429 4430 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4428 def items @items end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server will know to
ignore the request if it has already been completed. The server will guarantee
that for at least 60 minutes since the first request. For example, consider a
situation where you make an initial request and the request times out. If you
make the request again with the same request ID, the server can check if
original operation with the same request ID was received, and if so, will
ignore the second request. This prevents clients from accidentally creating
duplicate commitments. The request ID must be a valid UUID with the exception
that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
4442 4443 4444 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4442 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4449 4450 4451 4452 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4449 def update!(**args) @items = args[:items] if args.key?(:items) @request_id = args[:request_id] if args.key?(:request_id) end |