Class: Google::Apis::NetworksecurityV1beta1::RemoveAddressGroupItemsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Request used by the RemoveAddressGroupItems method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoveAddressGroupItemsRequest

Returns a new instance of RemoveAddressGroupItemsRequest.



4182
4183
4184
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4182

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<String>

Required. List of items to remove. Corresponds to the JSON property items

Returns:

  • (Array<String>)


4166
4167
4168
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4166

def items
  @items
end

#request_idString

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments. The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


4180
4181
4182
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4180

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4187
4188
4189
4190
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4187

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @request_id = args[:request_id] if args.key?(:request_id)
end