Class: Google::Apis::NetworksecurityV1beta1::Rule
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::Rule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Specification of rules.
Instance Attribute Summary collapse
-
#destinations ⇒ Array<Google::Apis::NetworksecurityV1beta1::Destination>
Optional.
-
#sources ⇒ Array<Google::Apis::NetworksecurityV1beta1::Source>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rule
constructor
A new instance of Rule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rule
Returns a new instance of Rule.
4477 4478 4479 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4477 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destinations ⇒ Array<Google::Apis::NetworksecurityV1beta1::Destination>
Optional. List of attributes for the traffic destination. All of the
destinations must match. A destination is a match if a request matches all the
specified hosts, ports, methods and headers. If not set, the action specified
in the 'action' field will be applied without any rule checks for the
destination.
Corresponds to the JSON property destinations
4467 4468 4469 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4467 def destinations @destinations end |
#sources ⇒ Array<Google::Apis::NetworksecurityV1beta1::Source>
Optional. List of attributes for the traffic source. All of the sources must
match. A source is a match if both principals and ip_blocks match. If not set,
the action specified in the 'action' field will be applied without any rule
checks for the source.
Corresponds to the JSON property sources
4475 4476 4477 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4475 def sources @sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4482 4483 4484 4485 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4482 def update!(**args) @destinations = args[:destinations] if args.key?(:destinations) @sources = args[:sources] if args.key?(:sources) end |