Class: Google::Apis::NetworksecurityV1beta1::Rule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Specification of rules.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Rule

Returns a new instance of Rule.



4306
4307
4308
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4306

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationsArray<Google::Apis::NetworksecurityV1beta1::Destination>

Optional. List of attributes for the traffic destination. All of the destinations must match. A destination is a match if a request matches all the specified hosts, ports, methods and headers. If not set, the action specified in the 'action' field will be applied without any rule checks for the destination. Corresponds to the JSON property destinations



4296
4297
4298
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4296

def destinations
  @destinations
end

#sourcesArray<Google::Apis::NetworksecurityV1beta1::Source>

Optional. List of attributes for the traffic source. All of the sources must match. A source is a match if both principals and ip_blocks match. If not set, the action specified in the 'action' field will be applied without any rule checks for the source. Corresponds to the JSON property sources



4304
4305
4306
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4304

def sources
  @sources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4311
4312
4313
4314
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4311

def update!(**args)
  @destinations = args[:destinations] if args.key?(:destinations)
  @sources = args[:sources] if args.key?(:sources)
end