Class: Google::Apis::NetworksecurityV1beta1::SacAttachmentSacAttachmentSymantecOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Fields specific to attachments associated with Symantec Cloud SWG.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SacAttachmentSacAttachmentSymantecOptions

Returns a new instance of SacAttachmentSacAttachmentSymantecOptions.



4322
4323
4324
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4322

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#symantec_location_nameString

Immutable. Name to be used when creating a location on the customer's behalf in Symantec's Location API. Not to be confused with Google Cloud locations. Corresponds to the JSON property symantecLocationName

Returns:

  • (String)


4314
4315
4316
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4314

def symantec_location_name
  @symantec_location_name
end

#symantec_siteString

Immutable. Symantec data center identifier that this attachment will connect to. Corresponds to the JSON property symantecSite

Returns:

  • (String)


4320
4321
4322
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4320

def symantec_site
  @symantec_site
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4327
4328
4329
4330
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4327

def update!(**args)
  @symantec_location_name = args[:symantec_location_name] if args.key?(:symantec_location_name)
  @symantec_site = args[:symantec_site] if args.key?(:symantec_site)
end