Class: Google::Apis::NetworksecurityV1beta1::SecurityProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

SecurityProfile is a resource that defines the behavior for one of many ProfileTypes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityProfile

Returns a new instance of SecurityProfile.



4792
4793
4794
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Resource creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


4728
4729
4730
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4728

def create_time
  @create_time
end

#custom_intercept_profileGoogle::Apis::NetworksecurityV1beta1::CustomInterceptProfile

CustomInterceptProfile defines in-band integration behavior (intercept). It is used by firewall rules with an APPLY_SECURITY_PROFILE_GROUP action. Corresponds to the JSON property customInterceptProfile



4734
4735
4736
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4734

def custom_intercept_profile
  @custom_intercept_profile
end

#custom_mirroring_profileGoogle::Apis::NetworksecurityV1beta1::CustomMirroringProfile

CustomMirroringProfile defines out-of-band integration behavior (mirroring). It is used by mirroring rules with a MIRROR action. Corresponds to the JSON property customMirroringProfile



4740
4741
4742
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4740

def custom_mirroring_profile
  @custom_mirroring_profile
end

#descriptionString

Optional. An optional description of the profile. Max length 512 characters. Corresponds to the JSON property description

Returns:

  • (String)


4745
4746
4747
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4745

def description
  @description
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4752
4753
4754
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4752

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4757
4758
4759
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4757

def labels
  @labels
end

#nameString

Immutable. Identifier. Name of the SecurityProfile resource. It matches pattern projects|organizations/*/locations/location/securityProfiles/ security_profile`. Corresponds to the JSON propertyname`

Returns:

  • (String)


4764
4765
4766
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4764

def name
  @name
end

#threat_prevention_profileGoogle::Apis::NetworksecurityV1beta1::ThreatPreventionProfile

ThreatPreventionProfile defines an action for specific threat signatures or severity levels. Corresponds to the JSON property threatPreventionProfile



4770
4771
4772
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4770

def threat_prevention_profile
  @threat_prevention_profile
end

#typeString

Immutable. The single ProfileType that the SecurityProfile resource configures. Corresponds to the JSON property type

Returns:

  • (String)


4775
4776
4777
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4775

def type
  @type
end

#update_timeString

Output only. Last resource update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


4780
4781
4782
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4780

def update_time
  @update_time
end

#url_filtering_profileGoogle::Apis::NetworksecurityV1beta1::UrlFilteringProfile

UrlFilteringProfile defines filters based on URL. Corresponds to the JSON property urlFilteringProfile



4785
4786
4787
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4785

def url_filtering_profile
  @url_filtering_profile
end

#wildfire_analysis_profileGoogle::Apis::NetworksecurityV1beta1::WildfireAnalysisProfile

WildfireAnalysisProfile defines Palo Alto Networks WildFire behavior. Corresponds to the JSON property wildfireAnalysisProfile



4790
4791
4792
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4790

def wildfire_analysis_profile
  @wildfire_analysis_profile
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4797

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile)
  @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
  @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile)
  @wildfire_analysis_profile = args[:wildfire_analysis_profile] if args.key?(:wildfire_analysis_profile)
end