Class: Google::Apis::NetworksecurityV1beta1::SecurityProfile
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::SecurityProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
SecurityProfile is a resource that defines the behavior for one of many ProfileTypes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_intercept_profile ⇒ Google::Apis::NetworksecurityV1beta1::CustomInterceptProfile
CustomInterceptProfile defines in-band integration behavior (intercept).
-
#custom_mirroring_profile ⇒ Google::Apis::NetworksecurityV1beta1::CustomMirroringProfile
CustomMirroringProfile defines out-of-band integration behavior (mirroring).
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#threat_prevention_profile ⇒ Google::Apis::NetworksecurityV1beta1::ThreatPreventionProfile
ThreatPreventionProfile defines an action for specific threat signatures or severity levels.
-
#type ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
-
#url_filtering_profile ⇒ Google::Apis::NetworksecurityV1beta1::UrlFilteringProfile
UrlFilteringProfile defines filters based on URL.
-
#wildfire_analysis_profile ⇒ Google::Apis::NetworksecurityV1beta1::WildfireAnalysisProfile
WildfireAnalysisProfile defines Palo Alto Networks WildFire behavior.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityProfile
constructor
A new instance of SecurityProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityProfile
Returns a new instance of SecurityProfile.
4792 4793 4794 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4792 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Resource creation timestamp.
Corresponds to the JSON property createTime
4728 4729 4730 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4728 def create_time @create_time end |
#custom_intercept_profile ⇒ Google::Apis::NetworksecurityV1beta1::CustomInterceptProfile
CustomInterceptProfile defines in-band integration behavior (intercept). It is
used by firewall rules with an APPLY_SECURITY_PROFILE_GROUP action.
Corresponds to the JSON property customInterceptProfile
4734 4735 4736 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4734 def custom_intercept_profile @custom_intercept_profile end |
#custom_mirroring_profile ⇒ Google::Apis::NetworksecurityV1beta1::CustomMirroringProfile
CustomMirroringProfile defines out-of-band integration behavior (mirroring).
It is used by mirroring rules with a MIRROR action.
Corresponds to the JSON property customMirroringProfile
4740 4741 4742 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4740 def custom_mirroring_profile @custom_mirroring_profile end |
#description ⇒ String
Optional. An optional description of the profile. Max length 512 characters.
Corresponds to the JSON property description
4745 4746 4747 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4745 def description @description end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
4752 4753 4754 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4752 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
4757 4758 4759 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4757 def labels @labels end |
#name ⇒ String
Immutable. Identifier. Name of the SecurityProfile resource. It matches
pattern projects|organizations/*/locations/location/securityProfiles/
security_profile`.
Corresponds to the JSON propertyname`
4764 4765 4766 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4764 def name @name end |
#threat_prevention_profile ⇒ Google::Apis::NetworksecurityV1beta1::ThreatPreventionProfile
ThreatPreventionProfile defines an action for specific threat signatures or
severity levels.
Corresponds to the JSON property threatPreventionProfile
4770 4771 4772 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4770 def threat_prevention_profile @threat_prevention_profile end |
#type ⇒ String
Immutable. The single ProfileType that the SecurityProfile resource configures.
Corresponds to the JSON property type
4775 4776 4777 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4775 def type @type end |
#update_time ⇒ String
Output only. Last resource update timestamp.
Corresponds to the JSON property updateTime
4780 4781 4782 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4780 def update_time @update_time end |
#url_filtering_profile ⇒ Google::Apis::NetworksecurityV1beta1::UrlFilteringProfile
UrlFilteringProfile defines filters based on URL.
Corresponds to the JSON property urlFilteringProfile
4785 4786 4787 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4785 def url_filtering_profile @url_filtering_profile end |
#wildfire_analysis_profile ⇒ Google::Apis::NetworksecurityV1beta1::WildfireAnalysisProfile
WildfireAnalysisProfile defines Palo Alto Networks WildFire behavior.
Corresponds to the JSON property wildfireAnalysisProfile
4790 4791 4792 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4790 def wildfire_analysis_profile @wildfire_analysis_profile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4797 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile) @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile) @wildfire_analysis_profile = args[:wildfire_analysis_profile] if args.key?(:wildfire_analysis_profile) end |