Class: Google::Apis::NetworksecurityV1beta1::SecurityProfile
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::SecurityProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
SecurityProfile is a resource that defines the behavior for one of many ProfileTypes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_intercept_profile ⇒ Google::Apis::NetworksecurityV1beta1::CustomInterceptProfile
CustomInterceptProfile defines in-band integration behavior (intercept).
-
#custom_mirroring_profile ⇒ Google::Apis::NetworksecurityV1beta1::CustomMirroringProfile
CustomMirroringProfile defines out-of-band integration behavior (mirroring).
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#threat_prevention_profile ⇒ Google::Apis::NetworksecurityV1beta1::ThreatPreventionProfile
ThreatPreventionProfile defines an action for specific threat signatures or severity levels.
-
#type ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
-
#url_filtering_profile ⇒ Google::Apis::NetworksecurityV1beta1::UrlFilteringProfile
UrlFilteringProfile defines filters based on URL.
-
#wildfire_analysis_profile ⇒ Google::Apis::NetworksecurityV1beta1::WildfireAnalysisProfile
WildfireAnalysisProfile defines Palo Alto Networks WildFire behavior.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityProfile
constructor
A new instance of SecurityProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityProfile
Returns a new instance of SecurityProfile.
4784 4785 4786 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4784 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Resource creation timestamp.
Corresponds to the JSON property createTime
4720 4721 4722 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4720 def create_time @create_time end |
#custom_intercept_profile ⇒ Google::Apis::NetworksecurityV1beta1::CustomInterceptProfile
CustomInterceptProfile defines in-band integration behavior (intercept). It is
used by firewall rules with an APPLY_SECURITY_PROFILE_GROUP action.
Corresponds to the JSON property customInterceptProfile
4726 4727 4728 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4726 def custom_intercept_profile @custom_intercept_profile end |
#custom_mirroring_profile ⇒ Google::Apis::NetworksecurityV1beta1::CustomMirroringProfile
CustomMirroringProfile defines out-of-band integration behavior (mirroring).
It is used by mirroring rules with a MIRROR action.
Corresponds to the JSON property customMirroringProfile
4732 4733 4734 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4732 def custom_mirroring_profile @custom_mirroring_profile end |
#description ⇒ String
Optional. An optional description of the profile. Max length 512 characters.
Corresponds to the JSON property description
4737 4738 4739 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4737 def description @description end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
4744 4745 4746 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4744 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
4749 4750 4751 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4749 def labels @labels end |
#name ⇒ String
Immutable. Identifier. Name of the SecurityProfile resource. It matches
pattern projects|organizations/*/locations/location/securityProfiles/
security_profile`.
Corresponds to the JSON propertyname`
4756 4757 4758 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4756 def name @name end |
#threat_prevention_profile ⇒ Google::Apis::NetworksecurityV1beta1::ThreatPreventionProfile
ThreatPreventionProfile defines an action for specific threat signatures or
severity levels.
Corresponds to the JSON property threatPreventionProfile
4762 4763 4764 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4762 def threat_prevention_profile @threat_prevention_profile end |
#type ⇒ String
Immutable. The single ProfileType that the SecurityProfile resource configures.
Corresponds to the JSON property type
4767 4768 4769 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4767 def type @type end |
#update_time ⇒ String
Output only. Last resource update timestamp.
Corresponds to the JSON property updateTime
4772 4773 4774 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4772 def update_time @update_time end |
#url_filtering_profile ⇒ Google::Apis::NetworksecurityV1beta1::UrlFilteringProfile
UrlFilteringProfile defines filters based on URL.
Corresponds to the JSON property urlFilteringProfile
4777 4778 4779 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4777 def url_filtering_profile @url_filtering_profile end |
#wildfire_analysis_profile ⇒ Google::Apis::NetworksecurityV1beta1::WildfireAnalysisProfile
WildfireAnalysisProfile defines Palo Alto Networks WildFire behavior.
Corresponds to the JSON property wildfireAnalysisProfile
4782 4783 4784 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4782 def wildfire_analysis_profile @wildfire_analysis_profile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4789 4790 4791 4792 4793 4794 4795 4796 4797 4798 4799 4800 4801 4802 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4789 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile) @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile) @wildfire_analysis_profile = args[:wildfire_analysis_profile] if args.key?(:wildfire_analysis_profile) end |