Class: Google::Apis::NetworksecurityV1beta1::SecurityProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

SecurityProfile is a resource that defines the behavior for one of many ProfileTypes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityProfile

Returns a new instance of SecurityProfile.



4525
4526
4527
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4525

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Resource creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


4466
4467
4468
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4466

def create_time
  @create_time
end

#custom_intercept_profileGoogle::Apis::NetworksecurityV1beta1::CustomInterceptProfile

CustomInterceptProfile defines in-band integration behavior (intercept). It is used by firewall rules with an APPLY_SECURITY_PROFILE_GROUP action. Corresponds to the JSON property customInterceptProfile



4472
4473
4474
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4472

def custom_intercept_profile
  @custom_intercept_profile
end

#custom_mirroring_profileGoogle::Apis::NetworksecurityV1beta1::CustomMirroringProfile

CustomMirroringProfile defines out-of-band integration behavior (mirroring). It is used by mirroring rules with a MIRROR action. Corresponds to the JSON property customMirroringProfile



4478
4479
4480
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4478

def custom_mirroring_profile
  @custom_mirroring_profile
end

#descriptionString

Optional. An optional description of the profile. Max length 512 characters. Corresponds to the JSON property description

Returns:

  • (String)


4483
4484
4485
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4483

def description
  @description
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4490
4491
4492
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4490

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4495
4496
4497
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4495

def labels
  @labels
end

#nameString

Immutable. Identifier. Name of the SecurityProfile resource. It matches pattern projects|organizations/*/locations/location/securityProfiles/ security_profile`. Corresponds to the JSON propertyname`

Returns:

  • (String)


4502
4503
4504
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4502

def name
  @name
end

#threat_prevention_profileGoogle::Apis::NetworksecurityV1beta1::ThreatPreventionProfile

ThreatPreventionProfile defines an action for specific threat signatures or severity levels. Corresponds to the JSON property threatPreventionProfile



4508
4509
4510
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4508

def threat_prevention_profile
  @threat_prevention_profile
end

#typeString

Immutable. The single ProfileType that the SecurityProfile resource configures. Corresponds to the JSON property type

Returns:

  • (String)


4513
4514
4515
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4513

def type
  @type
end

#update_timeString

Output only. Last resource update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


4518
4519
4520
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4518

def update_time
  @update_time
end

#url_filtering_profileGoogle::Apis::NetworksecurityV1beta1::UrlFilteringProfile

UrlFilteringProfile defines filters based on URL. Corresponds to the JSON property urlFilteringProfile



4523
4524
4525
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4523

def url_filtering_profile
  @url_filtering_profile
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4530

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile)
  @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
  @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile)
end