Class: Google::Apis::NetworksecurityV1beta1::SecurityProfileGroup
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::SecurityProfileGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
SecurityProfileGroup is a resource that defines the behavior for various ProfileTypes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_intercept_profile ⇒ String
Optional.
-
#custom_mirroring_profile ⇒ String
Optional.
-
#data_path_id ⇒ Fixnum
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#threat_prevention_profile ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#url_filtering_profile ⇒ String
Optional.
-
#wildfire_analysis_profile ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityProfileGroup
constructor
A new instance of SecurityProfileGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityProfileGroup
Returns a new instance of SecurityProfileGroup.
4887 4888 4889 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4887 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Resource creation timestamp.
Corresponds to the JSON property createTime
4821 4822 4823 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4821 def create_time @create_time end |
#custom_intercept_profile ⇒ String
Optional. Reference to a SecurityProfile with the CustomIntercept
configuration.
Corresponds to the JSON property customInterceptProfile
4827 4828 4829 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4827 def custom_intercept_profile @custom_intercept_profile end |
#custom_mirroring_profile ⇒ String
Optional. Reference to a SecurityProfile with the CustomMirroring
configuration.
Corresponds to the JSON property customMirroringProfile
4833 4834 4835 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4833 def custom_mirroring_profile @custom_mirroring_profile end |
#data_path_id ⇒ Fixnum
Output only. Identifier used by the data-path. Unique within container,
location.
Corresponds to the JSON property dataPathId
4839 4840 4841 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4839 def data_path_id @data_path_id end |
#description ⇒ String
Optional. An optional description of the profile group. Max length 2048
characters.
Corresponds to the JSON property description
4845 4846 4847 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4845 def description @description end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
4852 4853 4854 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4852 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
4857 4858 4859 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4857 def labels @labels end |
#name ⇒ String
Immutable. Identifier. Name of the SecurityProfileGroup resource. It matches
pattern projects|organizations/*/locations/location/securityProfileGroups/
security_profile_group`.
Corresponds to the JSON propertyname`
4864 4865 4866 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4864 def name @name end |
#threat_prevention_profile ⇒ String
Optional. Reference to a SecurityProfile with the ThreatPrevention
configuration.
Corresponds to the JSON property threatPreventionProfile
4870 4871 4872 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4870 def threat_prevention_profile @threat_prevention_profile end |
#update_time ⇒ String
Output only. Last resource update timestamp.
Corresponds to the JSON property updateTime
4875 4876 4877 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4875 def update_time @update_time end |
#url_filtering_profile ⇒ String
Optional. Reference to a SecurityProfile with the UrlFiltering configuration.
Corresponds to the JSON property urlFilteringProfile
4880 4881 4882 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4880 def url_filtering_profile @url_filtering_profile end |
#wildfire_analysis_profile ⇒ String
Optional. Reference to a SecurityProfile with the WildFire configuration.
Corresponds to the JSON property wildfireAnalysisProfile
4885 4886 4887 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4885 def wildfire_analysis_profile @wildfire_analysis_profile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4892 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile) @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile) @data_path_id = args[:data_path_id] if args.key?(:data_path_id) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile) @update_time = args[:update_time] if args.key?(:update_time) @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile) @wildfire_analysis_profile = args[:wildfire_analysis_profile] if args.key?(:wildfire_analysis_profile) end |