Class: Google::Apis::NetworksecurityV1beta1::SecurityProfileGroup
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::SecurityProfileGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
SecurityProfileGroup is a resource that defines the behavior for various ProfileTypes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_intercept_profile ⇒ String
Optional.
-
#custom_mirroring_profile ⇒ String
Optional.
-
#data_path_id ⇒ Fixnum
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#threat_prevention_profile ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#url_filtering_profile ⇒ String
Optional.
-
#wildfire_analysis_profile ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityProfileGroup
constructor
A new instance of SecurityProfileGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityProfileGroup
Returns a new instance of SecurityProfileGroup.
4879 4880 4881 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4879 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Resource creation timestamp.
Corresponds to the JSON property createTime
4813 4814 4815 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4813 def create_time @create_time end |
#custom_intercept_profile ⇒ String
Optional. Reference to a SecurityProfile with the CustomIntercept
configuration.
Corresponds to the JSON property customInterceptProfile
4819 4820 4821 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4819 def custom_intercept_profile @custom_intercept_profile end |
#custom_mirroring_profile ⇒ String
Optional. Reference to a SecurityProfile with the CustomMirroring
configuration.
Corresponds to the JSON property customMirroringProfile
4825 4826 4827 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4825 def custom_mirroring_profile @custom_mirroring_profile end |
#data_path_id ⇒ Fixnum
Output only. Identifier used by the data-path. Unique within container,
location.
Corresponds to the JSON property dataPathId
4831 4832 4833 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4831 def data_path_id @data_path_id end |
#description ⇒ String
Optional. An optional description of the profile group. Max length 2048
characters.
Corresponds to the JSON property description
4837 4838 4839 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4837 def description @description end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
4844 4845 4846 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4844 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
4849 4850 4851 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4849 def labels @labels end |
#name ⇒ String
Immutable. Identifier. Name of the SecurityProfileGroup resource. It matches
pattern projects|organizations/*/locations/location/securityProfileGroups/
security_profile_group`.
Corresponds to the JSON propertyname`
4856 4857 4858 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4856 def name @name end |
#threat_prevention_profile ⇒ String
Optional. Reference to a SecurityProfile with the ThreatPrevention
configuration.
Corresponds to the JSON property threatPreventionProfile
4862 4863 4864 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4862 def threat_prevention_profile @threat_prevention_profile end |
#update_time ⇒ String
Output only. Last resource update timestamp.
Corresponds to the JSON property updateTime
4867 4868 4869 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4867 def update_time @update_time end |
#url_filtering_profile ⇒ String
Optional. Reference to a SecurityProfile with the UrlFiltering configuration.
Corresponds to the JSON property urlFilteringProfile
4872 4873 4874 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4872 def url_filtering_profile @url_filtering_profile end |
#wildfire_analysis_profile ⇒ String
Optional. Reference to a SecurityProfile with the WildFire configuration.
Corresponds to the JSON property wildfireAnalysisProfile
4877 4878 4879 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4877 def wildfire_analysis_profile @wildfire_analysis_profile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4884 4885 4886 4887 4888 4889 4890 4891 4892 4893 4894 4895 4896 4897 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4884 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile) @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile) @data_path_id = args[:data_path_id] if args.key?(:data_path_id) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile) @update_time = args[:update_time] if args.key?(:update_time) @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile) @wildfire_analysis_profile = args[:wildfire_analysis_profile] if args.key?(:wildfire_analysis_profile) end |