Class: Google::Apis::NetworksecurityV1beta1::SecurityProfileGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

SecurityProfileGroup is a resource that defines the behavior for various ProfileTypes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityProfileGroup

Returns a new instance of SecurityProfileGroup.



4727
4728
4729
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4727

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Resource creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


4666
4667
4668
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4666

def create_time
  @create_time
end

#custom_intercept_profileString

Optional. Reference to a SecurityProfile with the CustomIntercept configuration. Corresponds to the JSON property customInterceptProfile

Returns:

  • (String)


4672
4673
4674
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4672

def custom_intercept_profile
  @custom_intercept_profile
end

#custom_mirroring_profileString

Optional. Reference to a SecurityProfile with the CustomMirroring configuration. Corresponds to the JSON property customMirroringProfile

Returns:

  • (String)


4678
4679
4680
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4678

def custom_mirroring_profile
  @custom_mirroring_profile
end

#data_path_idFixnum

Output only. Identifier used by the data-path. Unique within container, location. Corresponds to the JSON property dataPathId

Returns:

  • (Fixnum)


4684
4685
4686
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4684

def data_path_id
  @data_path_id
end

#descriptionString

Optional. An optional description of the profile group. Max length 2048 characters. Corresponds to the JSON property description

Returns:

  • (String)


4690
4691
4692
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4690

def description
  @description
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4697
4698
4699
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4697

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4702
4703
4704
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4702

def labels
  @labels
end

#nameString

Immutable. Identifier. Name of the SecurityProfileGroup resource. It matches pattern projects|organizations/*/locations/location/securityProfileGroups/ security_profile_group`. Corresponds to the JSON propertyname`

Returns:

  • (String)


4709
4710
4711
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4709

def name
  @name
end

#threat_prevention_profileString

Optional. Reference to a SecurityProfile with the ThreatPrevention configuration. Corresponds to the JSON property threatPreventionProfile

Returns:

  • (String)


4715
4716
4717
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4715

def threat_prevention_profile
  @threat_prevention_profile
end

#update_timeString

Output only. Last resource update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


4720
4721
4722
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4720

def update_time
  @update_time
end

#url_filtering_profileString

Optional. Reference to a SecurityProfile with the UrlFiltering configuration. Corresponds to the JSON property urlFilteringProfile

Returns:

  • (String)


4725
4726
4727
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4725

def url_filtering_profile
  @url_filtering_profile
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4732
4733
4734
4735
4736
4737
4738
4739
4740
4741
4742
4743
4744
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4732

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile)
  @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile)
  @data_path_id = args[:data_path_id] if args.key?(:data_path_id)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile)
  @update_time = args[:update_time] if args.key?(:update_time)
  @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile)
end