Class: Google::Apis::NetworksecurityV1beta1::SecurityProfileGroup
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::SecurityProfileGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
SecurityProfileGroup is a resource that defines the behavior for various ProfileTypes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_intercept_profile ⇒ String
Optional.
-
#custom_mirroring_profile ⇒ String
Optional.
-
#data_path_id ⇒ Fixnum
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#threat_prevention_profile ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#url_filtering_profile ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityProfileGroup
constructor
A new instance of SecurityProfileGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityProfileGroup
Returns a new instance of SecurityProfileGroup.
4727 4728 4729 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4727 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Resource creation timestamp.
Corresponds to the JSON property createTime
4666 4667 4668 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4666 def create_time @create_time end |
#custom_intercept_profile ⇒ String
Optional. Reference to a SecurityProfile with the CustomIntercept
configuration.
Corresponds to the JSON property customInterceptProfile
4672 4673 4674 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4672 def custom_intercept_profile @custom_intercept_profile end |
#custom_mirroring_profile ⇒ String
Optional. Reference to a SecurityProfile with the CustomMirroring
configuration.
Corresponds to the JSON property customMirroringProfile
4678 4679 4680 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4678 def custom_mirroring_profile @custom_mirroring_profile end |
#data_path_id ⇒ Fixnum
Output only. Identifier used by the data-path. Unique within container,
location.
Corresponds to the JSON property dataPathId
4684 4685 4686 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4684 def data_path_id @data_path_id end |
#description ⇒ String
Optional. An optional description of the profile group. Max length 2048
characters.
Corresponds to the JSON property description
4690 4691 4692 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4690 def description @description end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
4697 4698 4699 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4697 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
4702 4703 4704 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4702 def labels @labels end |
#name ⇒ String
Immutable. Identifier. Name of the SecurityProfileGroup resource. It matches
pattern projects|organizations/*/locations/location/securityProfileGroups/
security_profile_group`.
Corresponds to the JSON propertyname`
4709 4710 4711 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4709 def name @name end |
#threat_prevention_profile ⇒ String
Optional. Reference to a SecurityProfile with the ThreatPrevention
configuration.
Corresponds to the JSON property threatPreventionProfile
4715 4716 4717 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4715 def threat_prevention_profile @threat_prevention_profile end |
#update_time ⇒ String
Output only. Last resource update timestamp.
Corresponds to the JSON property updateTime
4720 4721 4722 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4720 def update_time @update_time end |
#url_filtering_profile ⇒ String
Optional. Reference to a SecurityProfile with the UrlFiltering configuration.
Corresponds to the JSON property urlFilteringProfile
4725 4726 4727 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4725 def url_filtering_profile @url_filtering_profile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4732 4733 4734 4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4732 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile) @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile) @data_path_id = args[:data_path_id] if args.key?(:data_path_id) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile) @update_time = args[:update_time] if args.key?(:update_time) @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile) end |