Class: Google::Apis::NetworksecurityV1beta1::SecurityProfileGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

SecurityProfileGroup is a resource that defines the behavior for various ProfileTypes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityProfileGroup

Returns a new instance of SecurityProfileGroup.



4706
4707
4708
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Resource creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


4645
4646
4647
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4645

def create_time
  @create_time
end

#custom_intercept_profileString

Optional. Reference to a SecurityProfile with the CustomIntercept configuration. Corresponds to the JSON property customInterceptProfile

Returns:

  • (String)


4651
4652
4653
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4651

def custom_intercept_profile
  @custom_intercept_profile
end

#custom_mirroring_profileString

Optional. Reference to a SecurityProfile with the CustomMirroring configuration. Corresponds to the JSON property customMirroringProfile

Returns:

  • (String)


4657
4658
4659
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4657

def custom_mirroring_profile
  @custom_mirroring_profile
end

#data_path_idFixnum

Output only. Identifier used by the data-path. Unique within container, location. Corresponds to the JSON property dataPathId

Returns:

  • (Fixnum)


4663
4664
4665
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4663

def data_path_id
  @data_path_id
end

#descriptionString

Optional. An optional description of the profile group. Max length 2048 characters. Corresponds to the JSON property description

Returns:

  • (String)


4669
4670
4671
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4669

def description
  @description
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4676
4677
4678
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4676

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4681
4682
4683
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4681

def labels
  @labels
end

#nameString

Immutable. Identifier. Name of the SecurityProfileGroup resource. It matches pattern projects|organizations/*/locations/location/securityProfileGroups/ security_profile_group`. Corresponds to the JSON propertyname`

Returns:

  • (String)


4688
4689
4690
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4688

def name
  @name
end

#threat_prevention_profileString

Optional. Reference to a SecurityProfile with the ThreatPrevention configuration. Corresponds to the JSON property threatPreventionProfile

Returns:

  • (String)


4694
4695
4696
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4694

def threat_prevention_profile
  @threat_prevention_profile
end

#update_timeString

Output only. Last resource update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


4699
4700
4701
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4699

def update_time
  @update_time
end

#url_filtering_profileString

Optional. Reference to a SecurityProfile with the UrlFiltering configuration. Corresponds to the JSON property urlFilteringProfile

Returns:

  • (String)


4704
4705
4706
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4704

def url_filtering_profile
  @url_filtering_profile
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4711
4712
4713
4714
4715
4716
4717
4718
4719
4720
4721
4722
4723
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4711

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile)
  @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile)
  @data_path_id = args[:data_path_id] if args.key?(:data_path_id)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile)
  @update_time = args[:update_time] if args.key?(:update_time)
  @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile)
end