Class: Google::Apis::NetworksecurityV1beta1::SecurityProfileGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

SecurityProfileGroup is a resource that defines the behavior for various ProfileTypes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityProfileGroup

Returns a new instance of SecurityProfileGroup.



4614
4615
4616
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4614

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Resource creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


4553
4554
4555
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4553

def create_time
  @create_time
end

#custom_intercept_profileString

Optional. Reference to a SecurityProfile with the CustomIntercept configuration. Corresponds to the JSON property customInterceptProfile

Returns:

  • (String)


4559
4560
4561
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4559

def custom_intercept_profile
  @custom_intercept_profile
end

#custom_mirroring_profileString

Optional. Reference to a SecurityProfile with the CustomMirroring configuration. Corresponds to the JSON property customMirroringProfile

Returns:

  • (String)


4565
4566
4567
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4565

def custom_mirroring_profile
  @custom_mirroring_profile
end

#data_path_idFixnum

Output only. Identifier used by the data-path. Unique within container, location. Corresponds to the JSON property dataPathId

Returns:

  • (Fixnum)


4571
4572
4573
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4571

def data_path_id
  @data_path_id
end

#descriptionString

Optional. An optional description of the profile group. Max length 2048 characters. Corresponds to the JSON property description

Returns:

  • (String)


4577
4578
4579
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4577

def description
  @description
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4584
4585
4586
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4584

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4589
4590
4591
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4589

def labels
  @labels
end

#nameString

Immutable. Identifier. Name of the SecurityProfileGroup resource. It matches pattern projects|organizations/*/locations/location/securityProfileGroups/ security_profile_group`. Corresponds to the JSON propertyname`

Returns:

  • (String)


4596
4597
4598
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4596

def name
  @name
end

#threat_prevention_profileString

Optional. Reference to a SecurityProfile with the ThreatPrevention configuration. Corresponds to the JSON property threatPreventionProfile

Returns:

  • (String)


4602
4603
4604
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4602

def threat_prevention_profile
  @threat_prevention_profile
end

#update_timeString

Output only. Last resource update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


4607
4608
4609
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4607

def update_time
  @update_time
end

#url_filtering_profileString

Optional. Reference to a SecurityProfile with the UrlFiltering configuration. Corresponds to the JSON property urlFilteringProfile

Returns:

  • (String)


4612
4613
4614
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4612

def url_filtering_profile
  @url_filtering_profile
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
4630
4631
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4619

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile)
  @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile)
  @data_path_id = args[:data_path_id] if args.key?(:data_path_id)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile)
  @update_time = args[:update_time] if args.key?(:update_time)
  @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile)
end