Class: Google::Apis::NetworksecurityV1beta1::ServerTlsPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

ServerTlsPolicy is a resource that specifies how a server should authenticate incoming requests. This resource itself does not affect configuration unless it is attached to a target HTTPS proxy or endpoint config selector resource. ServerTlsPolicy in the form accepted by Application Load Balancers can be attached only to TargetHttpsProxy with an EXTERNAL, EXTERNAL_MANAGED or INTERNAL_MANAGED load balancing scheme. Traffic Director compatible ServerTlsPolicies can be attached to EndpointPolicy and TargetHttpsProxy with Traffic Director INTERNAL_SELF_MANAGED load balancing scheme.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServerTlsPolicy

Returns a new instance of ServerTlsPolicy.



4696
4697
4698
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4696

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_openBoolean Also known as: allow_open?

This field applies only for Traffic Director policies. It is must be set to false for Application Load Balancer policies. Determines if server allows plaintext connections. If set to true, server allows plain text connections. By default, it is set to false. This setting is not exclusive of other encryption modes. For example, if allow_open and mtls_policy are set, server allows both plain text and mTLS connections. See documentation of other encryption modes to confirm compatibility. Consider using it if you wish to upgrade in place your deployment to TLS while having mixed TLS and non-TLS traffic reaching port :80. Corresponds to the JSON property allowOpen

Returns:

  • (Boolean)


4656
4657
4658
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4656

def allow_open
  @allow_open
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4662
4663
4664
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4662

def create_time
  @create_time
end

#descriptionString

Free-text description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


4667
4668
4669
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4667

def description
  @description
end

#labelsHash<String,String>

Set of label tags associated with the resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4672
4673
4674
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4672

def labels
  @labels
end

#mtls_policyGoogle::Apis::NetworksecurityV1beta1::MtlsPolicy

Specification of the MTLSPolicy. Corresponds to the JSON property mtlsPolicy



4677
4678
4679
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4677

def mtls_policy
  @mtls_policy
end

#nameString

Required. Name of the ServerTlsPolicy resource. It matches the pattern projects/*/locations/location/serverTlsPolicies/server_tls_policy` Corresponds to the JSON propertyname`

Returns:

  • (String)


4683
4684
4685
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4683

def name
  @name
end

#server_certificateGoogle::Apis::NetworksecurityV1beta1::GoogleCloudNetworksecurityV1beta1CertificateProvider

Specification of certificate provider. Defines the mechanism to obtain the certificate and private key for peer to peer authentication. Corresponds to the JSON property serverCertificate



4689
4690
4691
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4689

def server_certificate
  @server_certificate
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4694
4695
4696
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4694

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4701
4702
4703
4704
4705
4706
4707
4708
4709
4710
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4701

def update!(**args)
  @allow_open = args[:allow_open] if args.key?(:allow_open)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @mtls_policy = args[:mtls_policy] if args.key?(:mtls_policy)
  @name = args[:name] if args.key?(:name)
  @server_certificate = args[:server_certificate] if args.key?(:server_certificate)
  @update_time = args[:update_time] if args.key?(:update_time)
end