Class: Google::Apis::NetworksecurityV1beta1::ThreatOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Defines what action to take for a specific threat_id match.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ThreatOverride

Returns a new instance of ThreatOverride.



5097
5098
5099
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5097

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Required. Threat action override. For some threat types, only a subset of actions applies. Corresponds to the JSON property action

Returns:

  • (String)


5085
5086
5087
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5085

def action
  @action
end

#threat_idString

Required. Vendor-specific ID of a threat to override. Corresponds to the JSON property threatId

Returns:

  • (String)


5090
5091
5092
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5090

def threat_id
  @threat_id
end

#typeString

Output only. Type of the threat (read only). Corresponds to the JSON property type

Returns:

  • (String)


5095
5096
5097
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5095

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5102
5103
5104
5105
5106
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5102

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @threat_id = args[:threat_id] if args.key?(:threat_id)
  @type = args[:type] if args.key?(:type)
end