Class: Google::Apis::NetworksecurityV1beta1::ThreatOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Defines what action to take for a specific threat_id match.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ThreatOverride

Returns a new instance of ThreatOverride.



4923
4924
4925
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4923

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Required. Threat action override. For some threat types, only a subset of actions applies. Corresponds to the JSON property action

Returns:

  • (String)


4911
4912
4913
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4911

def action
  @action
end

#threat_idString

Required. Vendor-specific ID of a threat to override. Corresponds to the JSON property threatId

Returns:

  • (String)


4916
4917
4918
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4916

def threat_id
  @threat_id
end

#typeString

Output only. Type of the threat (read only). Corresponds to the JSON property type

Returns:

  • (String)


4921
4922
4923
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4921

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4928
4929
4930
4931
4932
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 4928

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @threat_id = args[:threat_id] if args.key?(:threat_id)
  @type = args[:type] if args.key?(:type)
end