Class: Google::Apis::NetworksecurityV1beta1::ValidationCa

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Specification of ValidationCA. Defines the mechanism to obtain the Certificate Authority certificate to validate the peer certificate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ValidationCa

Returns a new instance of ValidationCa.



5214
5215
5216
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5214

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_provider_instanceGoogle::Apis::NetworksecurityV1beta1::CertificateProviderInstance

Specification of a TLS certificate provider instance. Workloads may have one or more CertificateProvider instances (plugins) and one of them is enabled and configured by specifying this message. Workloads use the values from this message to locate and load the CertificateProvider instance configuration. Corresponds to the JSON property certificateProviderInstance



5207
5208
5209
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5207

def certificate_provider_instance
  @certificate_provider_instance
end

#grpc_endpointGoogle::Apis::NetworksecurityV1beta1::GoogleCloudNetworksecurityV1beta1GrpcEndpoint

Specification of the GRPC Endpoint. Corresponds to the JSON property grpcEndpoint



5212
5213
5214
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5212

def grpc_endpoint
  @grpc_endpoint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5219
5220
5221
5222
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5219

def update!(**args)
  @certificate_provider_instance = args[:certificate_provider_instance] if args.key?(:certificate_provider_instance)
  @grpc_endpoint = args[:grpc_endpoint] if args.key?(:grpc_endpoint)
end