Class: Google::Apis::NetworksecurityV1beta1::WildfireInlineCloudAnalysisRule
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::WildfireInlineCloudAnalysisRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
The list of file type configurations to be scanned by WildFire Inline Cloud Analysis.
Instance Attribute Summary collapse
-
#action ⇒ String
Required.
-
#custom_file_types ⇒ Google::Apis::NetworksecurityV1beta1::WildfireInlineCloudAnalysisRuleCustomFileTypes
The options to submit a custom list of file types for scan.
-
#direction ⇒ String
Required.
-
#file_selection_mode ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WildfireInlineCloudAnalysisRule
constructor
A new instance of WildfireInlineCloudAnalysisRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WildfireInlineCloudAnalysisRule
Returns a new instance of WildfireInlineCloudAnalysisRule.
5469 5470 5471 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5469 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Required. Action to take when a threat is detected using WildFire Inline Cloud
Analysis. The default Value is DENY.
Corresponds to the JSON property action
5451 5452 5453 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5451 def action @action end |
#custom_file_types ⇒ Google::Apis::NetworksecurityV1beta1::WildfireInlineCloudAnalysisRuleCustomFileTypes
The options to submit a custom list of file types for scan.
Corresponds to the JSON property customFileTypes
5456 5457 5458 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5456 def custom_file_types @custom_file_types end |
#direction ⇒ String
Required. Direction for the file to be analyzed by WildFire Inline Cloud
Analysis.
Corresponds to the JSON property direction
5462 5463 5464 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5462 def direction @direction end |
#file_selection_mode ⇒ String
Required. File selection mode for WildFire inline cloud analysis.
Corresponds to the JSON property fileSelectionMode
5467 5468 5469 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5467 def file_selection_mode @file_selection_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5474 5475 5476 5477 5478 5479 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5474 def update!(**args) @action = args[:action] if args.key?(:action) @custom_file_types = args[:custom_file_types] if args.key?(:custom_file_types) @direction = args[:direction] if args.key?(:direction) @file_selection_mode = args[:file_selection_mode] if args.key?(:file_selection_mode) end |