Class: Google::Apis::NetworksecurityV1beta1::WildfireSubmissionRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb

Overview

Defines the file types to be submitted for WildFire analysis and the direction of the traffic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WildfireSubmissionRule

Returns a new instance of WildfireSubmissionRule.



5656
5657
5658
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5656

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_file_typesGoogle::Apis::NetworksecurityV1beta1::WildfireSubmissionRuleCustomFileTypes

The options to submit a custom list of file types for scan. Corresponds to the JSON property customFileTypes



5644
5645
5646
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5644

def custom_file_types
  @custom_file_types
end

#directionString

Required. Direction for the files to be analyzed by WildFire. Corresponds to the JSON property direction

Returns:

  • (String)


5649
5650
5651
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5649

def direction
  @direction
end

#file_selection_modeString

Required. File selection mode for WildFire analysis. Corresponds to the JSON property fileSelectionMode

Returns:

  • (String)


5654
5655
5656
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5654

def file_selection_mode
  @file_selection_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5661
5662
5663
5664
5665
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5661

def update!(**args)
  @custom_file_types = args[:custom_file_types] if args.key?(:custom_file_types)
  @direction = args[:direction] if args.key?(:direction)
  @file_selection_mode = args[:file_selection_mode] if args.key?(:file_selection_mode)
end