Class: Google::Apis::NetworksecurityV1beta1::WildfireVerdictChangeRequest
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1beta1::WildfireVerdictChangeRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1beta1/classes.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb,
lib/google/apis/networksecurity_v1beta1/representations.rb
Overview
Message for a WildfireVerdictChangeRequest.
Instance Attribute Summary collapse
-
#comment ⇒ String
Required.
-
#create_time ⇒ String
Output only.
-
#file_name ⇒ String
Output only.
-
#file_type ⇒ String
Output only.
-
#final_verdict ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#new_verdict ⇒ String
Required.
-
#old_verdict ⇒ String
Output only.
-
#resolution_time ⇒ String
Output only.
-
#sha256 ⇒ String
Required.
-
#source_region ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#wildfire_verdict_change_request_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WildfireVerdictChangeRequest
constructor
A new instance of WildfireVerdictChangeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WildfireVerdictChangeRequest
Returns a new instance of WildfireVerdictChangeRequest.
5788 5789 5790 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5788 def initialize(**args) update!(**args) end |
Instance Attribute Details
#comment ⇒ String
Required. The justification for the verdict change request. Max length 2048
characters.
Corresponds to the JSON property comment
5712 5713 5714 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5712 def comment @comment end |
#create_time ⇒ String
Output only. The timestamp when the WildfireVerdictChangeRequest was created.
Corresponds to the JSON property createTime
5717 5718 5719 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5717 def create_time @create_time end |
#file_name ⇒ String
Output only. The file name of the Malware Sample.
Corresponds to the JSON property fileName
5722 5723 5724 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5722 def file_name @file_name end |
#file_type ⇒ String
Output only. The file type of the Malware Sample.
Corresponds to the JSON property fileType
5727 5728 5729 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5727 def file_type @file_type end |
#final_verdict ⇒ String
Output only. The final verdict of the Malware Sample.
Corresponds to the JSON property finalVerdict
5732 5733 5734 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5732 def final_verdict @final_verdict end |
#name ⇒ String
Output only. Identifier. The relative name of the WildfireVerdictChangeRequest.
Output only. This is a unique identifier generated by the third party API.
Format: organizations|projects/project_or_organization/locations/location/
firewallEndpoints/firewall_endpoint/wildfireVerdictChangeRequests/
wildfire_verdict_change_request_id Where wildfire_verdict_change_request_id
is the ID in the format: ^[0-9a-fA-F]8-[0-9a-fA-F]4-[0-9a-fA-F]4-[0-9a-
fA-F]4-[0-9a-fA-F]12$
Corresponds to the JSON property name
5743 5744 5745 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5743 def name @name end |
#new_verdict ⇒ String
Required. The suggested verdict to apply to the Malware Sample.
Corresponds to the JSON property newVerdict
5748 5749 5750 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5748 def new_verdict @new_verdict end |
#old_verdict ⇒ String
Output only. The original verdict of the Malware Sample.
Corresponds to the JSON property oldVerdict
5753 5754 5755 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5753 def old_verdict @old_verdict end |
#resolution_time ⇒ String
Output only. The timestamp when the WildfireVerdictChangeRequest was resolved.
Corresponds to the JSON property resolutionTime
5758 5759 5760 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5758 def resolution_time @resolution_time end |
#sha256 ⇒ String
Required. The SHA256 hash of the Malware Sample to change the verdict of.
Corresponds to the JSON property sha256
5763 5764 5765 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5763 def sha256 @sha256 end |
#source_region ⇒ String
Output only. The region of the file associated with the Malware Sample.
Corresponds to the JSON property sourceRegion
5768 5769 5770 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5768 def source_region @source_region end |
#state ⇒ String
Output only. The review state of the WildfireVerdictChangeRequest.
Corresponds to the JSON property state
5773 5774 5775 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5773 def state @state end |
#update_time ⇒ String
Output only. The timestamp when the WildfireVerdictChangeRequest was last
updated.
Corresponds to the JSON property updateTime
5779 5780 5781 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5779 def update_time @update_time end |
#wildfire_verdict_change_request_id ⇒ String
Output only. The ID of the WildfireVerdictChangeRequest. This is a unique
identifier generated by the third party API. Format: ^[0-9a-fA-F]8-[0-9a-fA-
F]4-[0-9a-fA-F]4-[0-9a-fA-F]4-[0-9a-fA-F]12$
Corresponds to the JSON property wildfireVerdictChangeRequestId
5786 5787 5788 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5786 def wildfire_verdict_change_request_id @wildfire_verdict_change_request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5793 5794 5795 5796 5797 5798 5799 5800 5801 5802 5803 5804 5805 5806 5807 5808 |
# File 'lib/google/apis/networksecurity_v1beta1/classes.rb', line 5793 def update!(**args) @comment = args[:comment] if args.key?(:comment) @create_time = args[:create_time] if args.key?(:create_time) @file_name = args[:file_name] if args.key?(:file_name) @file_type = args[:file_type] if args.key?(:file_type) @final_verdict = args[:final_verdict] if args.key?(:final_verdict) @name = args[:name] if args.key?(:name) @new_verdict = args[:new_verdict] if args.key?(:new_verdict) @old_verdict = args[:old_verdict] if args.key?(:old_verdict) @resolution_time = args[:resolution_time] if args.key?(:resolution_time) @sha256 = args[:sha256] if args.key?(:sha256) @source_region = args[:source_region] if args.key?(:source_region) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) @wildfire_verdict_change_request_id = args[:wildfire_verdict_change_request_id] if args.key?(:wildfire_verdict_change_request_id) end |